"use strict";
(self["webpackChunkLIB"] = self["webpackChunkLIB"] || []).push([[135],{

/***/ 992:
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   Nd: () => (/* binding */ getRpcErrorData),
/* harmony export */   SS: () => (/* binding */ isInternalError),
/* harmony export */   dt: () => (/* binding */ getErrorStack),
/* harmony export */   mg: () => (/* binding */ asRequestError)
/* harmony export */ });
/* unused harmony export mergeLogAndError */
/* harmony import */ var common_logger__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(8976);
/* harmony import */ var common_format_datetime__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(1061);


function asRequestError(e) {
    const re = e;
    if (re.rpcError) {
        return e;
    }
    return null;
}
function getRpcErrorData(e) {
    const re = asRequestError(e);
    if (re && re.rpcError && re.rpcError.data) {
        return re.rpcError.data;
    }
    return null;
}
function isInternalError(e) {
    const re = asRequestError(e);
    if (!re) {
        return true;
    }
    if (re.rpcError.code < 0) {
        return true;
    }
    return false;
}
function getErrorStack(e) {
    if (!e) {
        return "Unknown error";
    }
    let errorStack = e.stack;
    const re = asRequestError(e);
    if (re) {
        const ed = getRpcErrorData(e);
        if (ed && ed.stack) {
            // use golang stack if available
            errorStack = ed.stack;
        }
        else if (re.message) {
            // or just message
            errorStack = re.message;
        }
    }
    return errorStack;
}
function mergeLogAndError(log, e) {
    let formattedLog = "";
    if (log) {
        let lines = log.split("\n");
        for (let line of lines) {
            line = line.trim();
            let fallback = false;
            try {
                const obj = JSON.parse(line);
                if (obj.msg) {
                    let date = formatDate(new Date(obj.time), "en-US", DATE_FORMAT);
                    let level = levels[obj.level];
                    let { msg } = obj;
                    formattedLog += `${date} [${level}] ${msg}\n`;
                }
                else {
                    fallback = true;
                }
            }
            catch (e) {
                fallback = true;
            }
            if (fallback) {
                formattedLog += `${line}\n`;
            }
        }
    }
    return `${formattedLog}\n\nError stack:\n${getErrorStack(e)}\n`;
}


/***/ }),

/***/ 2325:
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   CH: () => (/* binding */ getCaveSummary)
/* harmony export */ });
/* unused harmony exports hookProgress, hookLogging, getErrorMessage */
/* harmony import */ var common_butlerd_messages__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(4713);

function hookProgress(convo, ctx) {
    convo.onNotification(messages.Progress, (params) => {
        ctx.emitProgress(params);
    });
}
function hookLogging(convo, logger) {
    convo.onNotification(messages.Log, async ({ level, message }) => {
        switch (level) {
            case "debug":
                logger.debug(message);
                break;
            case "info":
                logger.info(message);
                break;
            case "warning":
                logger.warn(message);
                break;
            case "error":
                logger.error(message);
                break;
            default:
                logger.info(`[${level}] ${message}`);
                break;
        }
    });
}
function getCaveSummary(cave) {
    return {
        id: cave.id,
        gameId: cave.game.id,
        lastTouchedAt: cave.stats.lastTouchedAt,
        secondsRun: cave.stats.secondsRun,
        installedSize: cave.installInfo.installedSize,
    };
}
function getErrorMessage(e) {
    if (!e) {
        return "Unknown error";
    }
    // TODO: this is a good place to do i18n on butlerd error codes!
    let errorMessage = e.message;
    const re = e.rpcError;
    if (re) {
        if (re.message) {
            // use just the json-rpc message if possible
            errorMessage = re.message;
        }
    }
    return errorMessage;
}


/***/ }),

/***/ 3656:
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   Ip: () => (/* binding */ getDownloadError),
/* harmony export */   Z: () => (/* binding */ formatError),
/* harmony export */   dK: () => (/* binding */ getInstallPlanInfoError)
/* harmony export */ });
/* unused harmony export getButlerdErrorFromTuple */
/* harmony import */ var common_butlerd_errors__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(992);
/* harmony import */ var underscore__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(9050);


function formatError(e, apiErrorPrefix) {
    const re = (0,common_butlerd_errors__WEBPACK_IMPORTED_MODULE_0__/* .asRequestError */ .mg)(e);
    if (re && re.rpcError) {
        const { code, data } = re.rpcError;
        if (data && data.apiError && apiErrorPrefix) {
            const { messages } = data.apiError;
            const message = (0,underscore__WEBPACK_IMPORTED_MODULE_1__/* .first */ .Ps)(messages);
            if (message) {
                const snakeCaseMessage = message.replace(/\s/g, "_").toLowerCase();
                return [
                    `errors.api.${apiErrorPrefix}.${snakeCaseMessage}`,
                    {
                        defaultValue: `{message}`,
                        message,
                    },
                ];
            }
        }
        const { message } = re.rpcError;
        return [
            `butlerd.codes.${code}`,
            {
                defaultValue: `{message}`,
                message,
            },
        ];
    }
    return e.message;
}
function getDownloadError(item) {
    return getButlerdErrorFromTuple(item);
}
function getInstallPlanInfoError(item) {
    return getButlerdErrorFromTuple(item);
}
function getButlerdErrorFromTuple(item) {
    if (!item.errorMessage) {
        return null;
    }
    let rawError = new Error(item.errorMessage);
    rawError.stack = item.error;
    rawError.rpcError = {
        code: item.errorCode,
        message: item.errorMessage,
        data: {
            stack: item.error,
        },
    };
    return rawError;
}


/***/ }),

/***/ 5379:
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   j: () => (/* binding */ fileSize)
/* harmony export */ });
// ported from https://github.com/dustin/go-humanize
// Si vis pacem, para bellum
const sizes = ["B", "KiB", "MiB", "GiB", "TiB", "PiB", "EiB"];
const base = 1024;
const logE1024 = Math.log(base);
function fileSize(s) {
    if (s < 10) {
        return `${s} B`;
    }
    const e = Math.floor(Math.log(s) / logE1024);
    const suffix = sizes[Math.trunc(e)];
    const val = Math.floor((s / Math.pow(base, e)) * 10 + 0.5) / 10;
    if (val < 10) {
        return `${val.toFixed(1)} ${suffix}`;
    }
    else {
        return `${val.toFixed(0)} ${suffix}`;
    }
}


/***/ }),

/***/ 5346:
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   $O: () => (/* binding */ formatUploadTitle),
/* harmony export */   A6: () => (/* binding */ formatBuildVersionInfo),
/* harmony export */   Pn: () => (/* binding */ formatUploadTitleFancy)
/* harmony export */ });
function formatUploadTitle(u) {
    return u ? u.displayName || u.filename : "?";
}
function clean(s) {
    return s
        .replace(/\.[a-zA-Z0-9]+$/, "")
        .replace(/[_-]/g, " ")
        .replace(/\s+/, " ");
}
function formatUploadTitleFancy(u) {
    if (u.displayName) {
        return u.displayName;
    }
    if (u.filename) {
        return clean(u.filename);
    }
    return "?";
}
function formatBuildVersionInfo(b) {
    if (!b) {
        return null;
    }
    if (b.userVersion) {
        return `v${b.userVersion}`;
    }
    return `#${b.version}`;
}


/***/ }),

/***/ 3961:
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   kr: () => (/* binding */ onNotification),
/* harmony export */   mK: () => (/* binding */ hookLogging),
/* harmony export */   rN: () => (/* binding */ onRequest)
/* harmony export */ });
/* unused harmony export convertMessage */
/* harmony import */ var common_logger__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(8976);
/* harmony import */ var common_butlerd_utils__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(2325);
/* harmony import */ var butlerd_lib_support__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(8240);



const hookLogging = (logger) => {
    return { type: "HOOK_LOGGING", logger: logger };
};
const onNotification = (messageName, callback) => {
    return {
        type: "ON_NOTIFICATION",
        messageName: messageName,
        callback: callback,
    };
};
const onRequest = (messageName, callback) => {
    return { type: "ON_REQUEST", messageName: messageName, callback: callback };
};
const convertMessage = (message) => {
    if (message.type === "HOOK_LOGGING") {
        const logger = new Logger(message.logger.sink, message.logger.name);
        return (convo) => utils.hookLogging(convo, logger);
    }
    else if (message.type === "ON_NOTIFICATION") {
        const notification = createNotification(message.messageName);
        return (convo) => convo.onNotification(notification, message.callback);
    }
    else if (message.type === "ON_REQUEST") {
        const request = createRequest(message.messageName);
        return (convo) => convo.onRequest(request, message.callback);
    }
    else {
        return (convo) => null;
    }
};


/***/ }),

/***/ 9082:
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {


// EXPORTS
__webpack_require__.d(__webpack_exports__, {
  Z: () => (/* binding */ SimpleSelect)
});

// UNUSED EXPORTS: FloaterSpacer

// EXTERNAL MODULE: ./node_modules/react/index.js
var react = __webpack_require__(7294);
// EXTERNAL MODULE: ./node_modules/classnames/index.js
var classnames = __webpack_require__(4184);
var classnames_default = /*#__PURE__*/__webpack_require__.n(classnames);
// EXTERNAL MODULE: ./src/renderer/styles.ts
var styles = __webpack_require__(5836);
// EXTERNAL MODULE: ./src/renderer/t.tsx + 2 modules
var t = __webpack_require__(9080);
;// CONCATENATED MODULE: ./src/renderer/basics/SimpleSelect/DefaultOptionComponent.tsx



const DefaultOptionDiv = styles/* default */.ZP.div `
  display: flex;
  flex-flow: row;
  align-items: center;
`;
class DefaultOptionComponent extends react.PureComponent {
    render() {
        const { option } = this.props;
        return react.createElement(DefaultOptionDiv, null, (0,t.T)(option.label));
    }
}

// EXTERNAL MODULE: ./node_modules/underscore/modules/index-all.js + 160 modules
var index_all = __webpack_require__(9050);
// EXTERNAL MODULE: ./src/renderer/basics/Filler.tsx
var Filler = __webpack_require__(4333);
// EXTERNAL MODULE: ./src/renderer/basics/Icon.tsx
var Icon = __webpack_require__(4198);
// EXTERNAL MODULE: ./src/renderer/basics/Floater.tsx
var Floater = __webpack_require__(3537);
;// CONCATENATED MODULE: ./src/renderer/basics/SimpleSelect/index.tsx








const FloaterSpacer = styles/* default */.ZP.div `
  width: 8px;
  flex-shrink: 0;
`;
const SimpleSelectDiv = styles/* default */.ZP.div `
  cursor: default;
  flex-grow: 1;

  background: ${(props) => props.theme.inputBackground};
  border: 1px solid ${(props) => props.theme.inputBorder};
  border-radius: 2px;

  transition: border-color: 0.1s;

  &:hover {
    border-color: ${(props) => props.theme.inputBorderFocused};
  }

  &:focus {
    outline: none;
  }
`;
const wrapperPadding = 10;
const iconPadding = 14;
const wrapperLike = (0,styles/* css */.iv) `
  ${styles/* singleLine */.U1};
  min-width: 180px;
  min-height: 2em;
  padding: ${wrapperPadding}px;
`;
const ValueWrapper = styles/* default */.ZP.div `
  ${wrapperLike};

  display: flex;
  flex-flow: row;
  align-items: center;
`;
const OptionWrapperDiv = styles/* default */.ZP.div `
  ${wrapperLike};
  background: ${(props) => props.theme.inputBackground};

  &.focused {
    background: ${(props) => props.theme.inputFocusedBackground};
  }

  &.selected {
    background: ${(props) => props.theme.inputSelectedBackground};
  }
`;
class OptionWrapper extends react.PureComponent {
    constructor() {
        super(...arguments);
        this.gotEl = (el) => {
            this.el = el;
            if (this.el) {
                this.updateScroll();
            }
        };
    }
    render() {
        return react.createElement(OptionWrapperDiv, Object.assign({}, this.props, { ref: this.gotEl }));
    }
    componentDidUpdate() {
        this.updateScroll();
    }
    updateScroll() {
        const { className } = this.props;
        if (/focused/.test(className)) {
            this.el.scrollIntoViewIfNeeded();
        }
    }
}
const Bar = styles/* default */.ZP.div `
  height: auto;
  width: 1px;
  background: ${(props) => props.theme.inputBorderFocused};
  align-self: stretch;
`;
const IconWrapper = styles/* default */.ZP.div `
  display: flex;
  flex-direction: row;
  align-items: center;
  justify-content: center;
  padding-right: ${iconPadding - wrapperPadding}px;
  padding-left: ${iconPadding}px;
`;
const OptionsAnchorDiv = styles/* default */.ZP.div `
  position: relative;
`;
const OptionsDiv = styles/* default */.ZP.div `
  position: absolute;
  top: 4px;
  left: 0;
  right: 0;
  padding: 4px 0;
  border-radius: 2px;

  border: 1px solid ${(props) => props.theme.inputBorder};

  z-index: 10;

  max-height: 400px;
  overflow-y: auto;
`;
const DummyOption = styles/* default */.ZP.div `
  display: flex;
  flex-flow: row;
  align-items: center;
  color: ${(props) => props.theme.ternaryText};
`;
const searchClearThreshold = 2000; // 2 seconds
const keyboardFocusTimeout = 250;
class SimpleSelect extends react.PureComponent {
    constructor(props, context) {
        super(props, context);
        this.onKeyDown = (ev) => {
            if (ev.key === "ArrowUp" ||
                ev.key === "PageUp" ||
                ev.key === "ArrowDown" ||
                ev.key === "PageDown" ||
                ev.key === "Home" ||
                ev.key === "End") {
                ev.preventDefault();
                const { options } = this.props;
                let { focusedValue } = this.state;
                if (!focusedValue) {
                    focusedValue = this.props.value;
                }
                if (!focusedValue) {
                    return;
                }
                let currentIndex = options.indexOf(focusedValue);
                let newIndex = currentIndex;
                if (ev.key === "ArrowUp") {
                    newIndex -= 1;
                }
                else if (ev.key === "ArrowDown") {
                    newIndex += 1;
                }
                else if (ev.key === "PageUp") {
                    newIndex -= 5;
                }
                else if (ev.key === "PageDown") {
                    newIndex += 5;
                }
                else if (ev.key === "Home") {
                    newIndex = 0;
                }
                else if (ev.key === "End") {
                    newIndex = options.length - 1;
                }
                if (newIndex < 0) {
                    newIndex = 0;
                }
                else if (newIndex >= options.length) {
                    newIndex = options.length - 1;
                }
                let newFocusedValue = options[newIndex];
                this.setState({
                    focusedValue: newFocusedValue,
                    lastKeyboardFocusAt: Date.now(),
                });
            }
            if (ev.key === "Enter") {
                this.close();
                this.props.onChange(this.state.focusedValue);
            }
        };
        this.onKeyPress = (ev) => {
            let search;
            let state = this.state;
            let prefix = Date.now() - state.lastSearchAt > searchClearThreshold
                ? ""
                : state.search;
            search = (prefix + ev.key).toLowerCase();
            this.setState({
                search,
                lastSearchAt: Date.now(),
            });
            const focusedValue = (0,index_all/* find */.sE)(this.props.options, (x) => typeof x.label === "string" && x.label.toLowerCase().startsWith(search));
            if (focusedValue) {
                this.setState({ focusedValue, lastKeyboardFocusAt: Date.now() });
            }
        };
        this.onOptionClick = (ev) => {
            ev.stopPropagation();
            const { onChange } = this.props;
            onChange(this.getValueForWrapper(ev.currentTarget));
            this.close();
        };
        this.onOptionMouseEnter = (ev) => {
            if (Date.now() - this.state.lastKeyboardFocusAt < keyboardFocusTimeout) {
                return;
            }
            this.setState({ focusedValue: this.getValueForWrapper(ev.currentTarget) });
        };
        this.onToggle = () => {
            this.setState((state) => ({
                open: !state.open,
            }));
            if (this.state.open) {
                this.close();
            }
            else {
                this.open();
            }
        };
        this.onBlur = () => {
            this.close();
        };
        this.state = {
            open: false,
            focusedValue: (0,index_all/* first */.Ps)(props.options),
            search: "",
            lastSearchAt: Date.now(),
            lastKeyboardFocusAt: 0,
        };
    }
    render() {
        const { value, OptionComponent = DefaultOptionComponent, isLoading, className, } = this.props;
        return (react.createElement(SimpleSelectDiv, { className: className, onClick: this.onToggle, onKeyDown: this.onKeyDown, onKeyPress: this.onKeyPress, tabIndex: -1, onBlur: this.onBlur },
            react.createElement(ValueWrapper, null,
                value ? (react.createElement(OptionComponent, { option: value })) : (react.createElement(DummyOption, null, "Select...")),
                react.createElement(Filler/* default */.Z, null),
                isLoading ? (react.createElement(react.Fragment, null,
                    react.createElement(Floater/* default */.Z, null),
                    react.createElement(FloaterSpacer, null))) : null,
                react.createElement(Bar, null),
                react.createElement(IconWrapper, null,
                    react.createElement(Icon/* default */.Z, { icon: "caret-down" }))),
            react.createElement(OptionsAnchorDiv, null, this.renderOptions())));
    }
    renderOptions() {
        const { open } = this.state;
        if (!open) {
            return null;
        }
        const { focusedValue } = this.state;
        const { options, value, OptionComponent = DefaultOptionComponent, } = this.props;
        return (react.createElement(OptionsDiv, null, options.map((option, i) => {
            const focused = focusedValue === option;
            const selected = value === option;
            return (react.createElement(OptionWrapper, { key: i, className: classnames_default()({ focused, selected }), "data-value": JSON.stringify(option.value), onClick: this.onOptionClick, onMouseEnter: this.onOptionMouseEnter },
                react.createElement(OptionComponent, { key: i, option: option })));
        })));
    }
    getValueForWrapper(el) {
        let dataValue = JSON.parse(el.dataset.value);
        const { options, onChange } = this.props;
        return (0,index_all/* findWhere */._e)(options, { value: dataValue });
    }
    open() {
        this.setState({ open: true, focusedValue: this.props.value });
    }
    close() {
        this.setState({ open: false });
    }
}


/***/ }),

/***/ 326:
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {


// EXPORTS
__webpack_require__.d(__webpack_exports__, {
  Z: () => (/* binding */ basics_UploadIcon)
});

// EXTERNAL MODULE: ./src/common/format/filesize.ts
var filesize = __webpack_require__(5379);
// EXTERNAL MODULE: ./src/common/constants/platform-data.ts
var platform_data = __webpack_require__(105);
// EXTERNAL MODULE: ./src/common/butlerd/messages.ts
var messages = __webpack_require__(4713);
;// CONCATENATED MODULE: ./src/main/reactors/make-upload-button.ts



function makeUploadButton(upload, opts = { showSize: true }) {
    let label = `${upload.displayName || upload.filename}`;
    let tags = [];
    if (upload.size > 0 && opts.showSize) {
        tags.push({
            label: `${fileSize(upload.size)}`,
        });
    }
    if (upload.demo) {
        tags.push({
            label: ["pick_update_upload.tags.demo"],
        });
    }
    for (const prop of Object.keys(platformData)) {
        if (upload[prop]) {
            tags.push({
                icon: platformData[prop].icon,
            });
        }
    }
    const timeAgo = {
        date: upload.updatedAt,
    };
    const icon = uploadIcon(upload) || "download";
    return { label, tags, icon, timeAgo };
}
const uploadIcons = {
    [messages/* UploadType */.AJ.Default]: "gamepad",
    [messages/* UploadType */.AJ.Flash]: "neutral",
    [messages/* UploadType */.AJ.Unity]: "neutral",
    [messages/* UploadType */.AJ.Java]: "neutral",
    [messages/* UploadType */.AJ.HTML]: "html5",
    [messages/* UploadType */.AJ.Soundtrack]: "music",
    [messages/* UploadType */.AJ.Book]: "book",
    [messages/* UploadType */.AJ.Video]: "video",
    [messages/* UploadType */.AJ.Documentation]: "book",
    [messages/* UploadType */.AJ.Mod]: "shirt",
    [messages/* UploadType */.AJ.AudioAssets]: "file-music",
    [messages/* UploadType */.AJ.GraphicalAssets]: "images",
    [messages/* UploadType */.AJ.Sourcecode]: "code",
    [messages/* UploadType */.AJ.Other]: "zip",
};
function uploadIcon(upload) {
    return uploadIcons[upload.type];
}
// TODO: i18n that stuff
const uploadTypeHints = {
    [messages/* UploadType */.AJ.Default]: "File",
    [messages/* UploadType */.AJ.Flash]: "Flash embed",
    [messages/* UploadType */.AJ.Unity]: "Unity embed (legacy)",
    [messages/* UploadType */.AJ.Java]: "Java applet",
    [messages/* UploadType */.AJ.HTML]: "HTML5 app",
    [messages/* UploadType */.AJ.Soundtrack]: "Soundtrack",
    [messages/* UploadType */.AJ.Book]: "Book",
    [messages/* UploadType */.AJ.Video]: "Video",
    [messages/* UploadType */.AJ.Documentation]: "Documentation",
    [messages/* UploadType */.AJ.Mod]: "Mod",
    [messages/* UploadType */.AJ.AudioAssets]: "Audio assets",
    [messages/* UploadType */.AJ.GraphicalAssets]: "Graphical assets",
    [messages/* UploadType */.AJ.Sourcecode]: "Source code",
    [messages/* UploadType */.AJ.Other]: "Other",
};
function uploadTypeHint(upload) {
    return uploadTypeHints[upload.type];
}

// EXTERNAL MODULE: ./node_modules/react/index.js
var react = __webpack_require__(7294);
// EXTERNAL MODULE: ./src/renderer/basics/Icon.tsx
var Icon = __webpack_require__(4198);
;// CONCATENATED MODULE: ./src/renderer/basics/UploadIcon.tsx



class UploadIcon extends react.PureComponent {
    render() {
        const { upload } = this.props;
        if (!upload) {
            return null;
        }
        return react.createElement(Icon/* default */.Z, { icon: uploadIcon(upload), hint: uploadTypeHint(upload) });
    }
}
/* harmony default export */ const basics_UploadIcon = (UploadIcon);


/***/ }),

/***/ 1608:
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   F: () => (/* binding */ ModalButtonSpacer),
/* harmony export */   Z: () => (/* binding */ ModalButtons)
/* harmony export */ });
/* harmony import */ var renderer_styles__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(5836);

const ModalButtons = renderer_styles__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .ZP.div `
  width: 100%;
  flex-shrink: 0;
  display: flex;
  flex-direction: row;
  justify-content: flex-end;
`;
const ModalButtonSpacer = renderer_styles__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .ZP.div `
  flex-shrink: 0;
  flex-grow: 0;
  width: 1em;
`;


/***/ }),

/***/ 5969:
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   R: () => (/* binding */ doAsync)
/* harmony export */ });
function doAsync(f) {
    f().catch((e) => {
        console.error(e.stack);
    });
}


/***/ }),

/***/ 9135:
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

// ESM COMPAT FLAG
__webpack_require__.r(__webpack_exports__);

// EXPORTS
__webpack_require__.d(__webpack_exports__, {
  "default": () => (/* binding */ modal_widgets_PlanInstall)
});

// EXTERNAL MODULE: ./node_modules/tslib/tslib.es6.js
var tslib_es6 = __webpack_require__(655);
// EXTERNAL MODULE: ./node_modules/classnames/index.js
var classnames = __webpack_require__(4184);
var classnames_default = /*#__PURE__*/__webpack_require__.n(classnames);
// EXTERNAL MODULE: ./src/common/actions/index.ts
var actions = __webpack_require__(2448);
// EXTERNAL MODULE: ./src/common/butlerd/messages.ts
var messages = __webpack_require__(4713);
// EXTERNAL MODULE: ./src/common/format/errors.ts
var errors = __webpack_require__(3656);
// EXTERNAL MODULE: ./src/common/format/filesize.ts
var filesize = __webpack_require__(5379);
// EXTERNAL MODULE: ./src/common/format/upload.ts
var upload = __webpack_require__(5346);
// EXTERNAL MODULE: ./src/renderer/modals.ts + 3 modules
var modals = __webpack_require__(9088);
// EXTERNAL MODULE: ./src/common/util/navigation.ts
var navigation = __webpack_require__(9471);
// EXTERNAL MODULE: ./node_modules/react/index.js
var react = __webpack_require__(7294);
// EXTERNAL MODULE: ./node_modules/react-intl/lib/src/components/injectIntl.js
var injectIntl = __webpack_require__(4806);
// EXTERNAL MODULE: ./src/renderer/basics/Button.tsx
var Button = __webpack_require__(6025);
// EXTERNAL MODULE: ./src/renderer/basics/Filler.tsx
var Filler = __webpack_require__(4333);
// EXTERNAL MODULE: ./src/renderer/basics/Floater.tsx
var Floater = __webpack_require__(3537);
// EXTERNAL MODULE: ./src/renderer/basics/Icon.tsx
var Icon = __webpack_require__(4198);
// EXTERNAL MODULE: ./src/renderer/basics/modal-styles.tsx
var modal_styles = __webpack_require__(1608);
// EXTERNAL MODULE: ./src/renderer/basics/SimpleSelect/index.tsx + 1 modules
var SimpleSelect = __webpack_require__(9082);
// EXTERNAL MODULE: ./src/renderer/butlerd/rcall.ts
var rcall = __webpack_require__(8472);
// EXTERNAL MODULE: ./src/renderer/helpers/doAsync.tsx
var doAsync = __webpack_require__(5969);
// EXTERNAL MODULE: ./src/renderer/hocs/butlerCaller/index.tsx + 1 modules
var butlerCaller = __webpack_require__(5617);
// EXTERNAL MODULE: ./src/renderer/hocs/hook.tsx
var hook = __webpack_require__(2263);
// EXTERNAL MODULE: ./src/renderer/hocs/watching.tsx
var watching = __webpack_require__(7538);
// EXTERNAL MODULE: ./src/renderer/logger/index.ts
var renderer_logger = __webpack_require__(5258);
// EXTERNAL MODULE: ./node_modules/styled-components/dist/styled-components.browser.esm.js + 4 modules
var styled_components_browser_esm = __webpack_require__(9163);
// EXTERNAL MODULE: ./src/renderer/styles.ts
var styles = __webpack_require__(5836);
;// CONCATENATED MODULE: ./src/renderer/modal-widgets/PlanInstall/select-common.tsx


const SelectValueDiv = styled_components_browser_esm["default"].div `
  display: flex;
  flex-flow: row wrap;
  align-items: center;

  .spacer {
    width: 0.5em;
    flex-shrink: 0;
  }

  .title {
    font-size: 90%;
    ${styles/* singleLine */.U1};
  }

  .tag {
    color: ${(props) => props.theme.secondaryText};
    text-shadow: none;

    font-size: 80%;
    padding-right: 8px;
    &:last-child {
      padding-right: 0;
    }

    border-radius: ${(props) => props.theme.borderRadii.explanation};
    flex-shrink: 0;
    ${styles/* singleLine */.U1};
  }
`;

// EXTERNAL MODULE: ./src/renderer/t.tsx + 2 modules
var t = __webpack_require__(9080);
;// CONCATENATED MODULE: ./src/renderer/modal-widgets/PlanInstall/InstallLocationOptionComponent.tsx





const InstallLocationOptionAdd = "_add";
function InstallLocationOptionComponent(props) {
    const l = props.option.location;
    if (!l) {
        return (react.createElement(SelectValueDiv, null,
            react.createElement(Icon/* default */.Z, { icon: "plus" }),
            react.createElement("div", { className: "spacer" }),
            react.createElement("div", { className: "title" }, (0,t.T)(props.option.label)),
            react.createElement("div", { className: "spacer" })));
    }
    return (react.createElement(SelectValueDiv, null,
        react.createElement(Icon/* default */.Z, { icon: "folder-open" }),
        react.createElement("div", { className: "spacer" }),
        react.createElement("div", { className: "title", title: l.path }, l.path),
        react.createElement("div", { className: "spacer" }),
        react.createElement("div", { className: "tag" }, (0,filesize/* fileSize */.j)(l.sizeInfo.freeSize)),
        react.createElement("div", { className: "spacer" })));
}

// EXTERNAL MODULE: ./src/renderer/basics/UploadIcon.tsx + 1 modules
var UploadIcon = __webpack_require__(326);
// EXTERNAL MODULE: ./src/renderer/basics/PlatformIcons/PlatformIcon.tsx
var PlatformIcon = __webpack_require__(1612);
;// CONCATENATED MODULE: ./src/renderer/modal-widgets/PlanInstall/UploadOptionComponent.tsx






function UploadOptionComponent(props) {
    const u = props.option.upload;
    return (react.createElement(SelectValueDiv, null,
        react.createElement(UploadIcon/* default */.Z, { upload: u }),
        react.createElement("div", { className: "spacer" }),
        react.createElement("div", { className: "title", title: (0,upload/* formatUploadTitle */.$O)(u) }, (0,upload/* formatUploadTitleFancy */.Pn)(u)),
        react.createElement(PlatformIcon/* default */.Z, { target: u, field: "windows", before: react.createElement("div", { className: "spacer" }) }),
        react.createElement(PlatformIcon/* default */.Z, { target: u, field: "linux", before: react.createElement("div", { className: "spacer" }) }),
        react.createElement(PlatformIcon/* default */.Z, { target: u, field: "osx", before: react.createElement("div", { className: "spacer" }) }),
        react.createElement("div", { className: "spacer" }),
        u.size > 0 ? react.createElement("div", { className: "tag" }, (0,filesize/* fileSize */.j)(u.size)) : null,
        u.demo ? react.createElement("div", { className: "tag" }, "demo") : null,
        react.createElement("div", { className: "spacer" })));
}

// EXTERNAL MODULE: ./src/renderer/modal-widgets/styles.tsx
var modal_widgets_styles = __webpack_require__(5871);
// EXTERNAL MODULE: ./src/renderer/pages/common/SortsAndFilters.tsx
var SortsAndFilters = __webpack_require__(7128);
// EXTERNAL MODULE: ./src/renderer/pages/common/StandardGameCover.tsx + 1 modules
var StandardGameCover = __webpack_require__(7792);
// EXTERNAL MODULE: ./src/renderer/pages/common/StandardGameDesc.tsx
var StandardGameDesc = __webpack_require__(5231);
// EXTERNAL MODULE: ./src/renderer/pages/PageStyles/boxes.tsx
var boxes = __webpack_require__(1625);
// EXTERNAL MODULE: ./node_modules/underscore/modules/index-all.js + 160 modules
var index_all = __webpack_require__(9050);
// EXTERNAL MODULE: ./src/common/logger/index.ts
var common_logger = __webpack_require__(8976);
// EXTERNAL MODULE: ./src/common/helpers/bridge.ts
var bridge = __webpack_require__(3961);
;// CONCATENATED MODULE: ./src/renderer/modal-widgets/PlanInstall/index.tsx
var PlanInstall_filename = "src/renderer/modal-widgets/PlanInstall/index.tsx";




































const logger = renderer_logger/* rendererLogger */.X.child(PlanInstall_filename);
const DiskSpaceIcon = (0,styles/* default */.ZP)((0,Icon/* default */.Z)) `
  margin-left: 8px;
`;
const ErrorContainer = styles/* default */.ZP.div `
  display: flex;
  flex-direction: row;
  align-items: center;
`;
const ErrorButtons = styles/* default */.ZP.div `
  flex-shrink: 0;
`;
const ErrorParagraph = styles/* default */.ZP.div `
  flex-grow: 1;
  line-height: 1.4;
  margin-right: 1em;
  color: ${(props) => props.theme.error};
  font-size: ${(props) => props.theme.fontSizes.baseText};
`;
const WideBox = (0,styles/* default */.ZP)((0,boxes/* Box */.xu)) `
  width: 100%;
`;
const SizeTable = styles/* default */.ZP.table `
  td {
    line-height: 2.5;
    padding-right: 0.4em;

    &.low {
      color: ${(props) => props.theme.error};
    }

    &.desc {
      color: ${(props) => props.theme.secondaryText};
    }

    strong {
      font-weight: bold;
    }

    i {
      font-size: 80%;
      opacity: 0.6;
    }
  }
`;
const PlanInstallDiv = (0,styles/* default */.ZP)((0,modal_widgets_styles/* ModalWidgetDiv */.U)) `
  min-width: 800px;
  max-width: 800px;
  min-height: 500px;
  max-height: 500px;
  display: flex;
  flex-direction: column;
`;
const SelectGroup = styles/* default */.ZP.div `
  width: 100%;
  display: flex;
  flex-direction: row;
  justify-content: flex-start;
  align-items: center;

  padding: 0.4em 0;
`;
const SelectHeader = styles/* default */.ZP.h3 `
  width: 150px;
`;
const StyledSelect = styles/* default */.ZP.select `
  flex-grow: 1;
  padding: 0.4em;
  border: 1px solid ${(props) => props.theme.filterBorder};
  border-radius: 3px;
  color: ${(props) => props.theme.baseText};

  background: rgba(0, 0, 0, 0.1);
  font-size: ${(props) => props.theme.fontSizes.large};
`;
var PlanStage;
(function (PlanStage) {
    PlanStage[PlanStage["Planning"] = 0] = "Planning";
})(PlanStage || (PlanStage = {}));
let PlanInstall = class PlanInstall extends react.PureComponent {
    constructor(props, context) {
        super(props, context);
        this.onShowError = () => {
            const { dispatch, intl } = this.props;
            const { game, error, log } = this.state;
            dispatch(actions/* actions */.N.openModal(modals/* default */.Z.showError.make({
                wind: (0,navigation/* ambientWind */.w)(),
                title: ["prompt.install_error.title"],
                message: (0,t/* TString */.m)(intl, (0,errors/* formatError */.Z)(error)),
                widgetParams: {
                    game,
                    rawError: error,
                    log,
                },
                buttons: ["ok"],
            })));
        };
        this.onInstallLocationChange = (item) => {
            if (item.value === InstallLocationOptionAdd) {
                const { dispatch } = this.props;
                dispatch(actions/* actions */.N.addInstallLocation({ wind: (0,navigation/* ambientWind */.w)() }));
                return;
            }
            this.setState({
                pickedInstallLocationId: item.value,
            });
            const { dispatch } = this.props;
            dispatch(actions/* actions */.N.updatePreferences({
                defaultInstallLocation: item.value,
            }));
        };
        this.onUploadChange = (item) => {
            const id = item.value;
            this.setState({
                pickedUploadId: id,
                busy: true,
            });
            this.pickUpload(id);
        };
        this.onCancel = (ev) => {
            this.close();
        };
        this.onInstall = (ev) => {
            this.close();
            (0,doAsync/* doAsync */.R)(async () => {
                const { dispatch } = this.props;
                const { game } = this.state;
                const { pickedInstallLocationId, pickedUploadId, uploads } = this.state;
                const upload = (0,index_all/* findWhere */._e)(uploads, { id: pickedUploadId });
                const logger = (0,common_logger/* recordingLogger */.CI)(renderer_logger/* rendererLogger */.X);
                logger.info(`Queuing install for ${game.url}...`);
                try {
                    // investigate
                    await (0,rcall/* rcall */.v)(messages/* InstallQueue */.vh, {
                        reason: messages/* DownloadReason */.tF.Install,
                        installLocationId: pickedInstallLocationId,
                        game,
                        upload,
                        build: upload.build,
                        queueDownload: true,
                        fastQueue: true,
                    }, [(0,bridge/* hookLogging */.mK)(logger)]);
                    logger.info(`Queued!`);
                    dispatch(actions/* actions */.N.downloadQueued({}));
                }
                catch (e) {
                    logger.error(`While queuing download: ${e.stack}`);
                    const { intl } = this.props;
                    dispatch(actions/* actions */.N.openModal(modals/* default */.Z.showError.make({
                        wind: (0,navigation/* ambientWind */.w)(),
                        title: ["prompt.install_error.title"],
                        message: (0,t/* TString */.m)(intl, (0,errors/* formatError */.Z)(e)),
                        widgetParams: {
                            game,
                            rawError: e,
                            log: logger.getLog(),
                        },
                        buttons: ["ok"],
                    })));
                }
            });
        };
        const { game } = props.modal.widgetParams;
        this.state = {
            stage: PlanStage.Planning,
            busy: true,
            game,
            gameId: game.id,
            installLocations: [],
        };
    }
    subscribe(watcher) {
        watcher.on(actions/* actions */.N.installLocationsChanged, async () => {
            this.loadInstallLocations();
        });
    }
    render() {
        return react.createElement(PlanInstallDiv, null, this.renderBody());
    }
    renderBody() {
        const { stage } = this.state;
        switch (stage) {
            case PlanStage.Planning:
                return this.renderPlanning();
        }
    }
    renderPlanning() {
        const { game, uploads, pickedUploadId, installLocations, pickedInstallLocationId, busy, error, } = this.state;
        let canInstall = !error && !busy;
        let locationOptions = installLocations.map((il) => {
            let val = {
                label: `${il.path} (${(0,filesize/* fileSize */.j)(il.sizeInfo.freeSize)} free)`,
                value: il.id,
                location: il,
            };
            return val;
        });
        locationOptions.push({
            label: (0,t._)("preferences.install_location.add"),
            value: InstallLocationOptionAdd,
            location: null,
        });
        let locationValue = (0,index_all/* findWhere */._e)(locationOptions, {
            value: pickedInstallLocationId,
        });
        let uploadOptions = [];
        if (uploads) {
            uploadOptions = uploads.map((u) => {
                let val = {
                    label: `${(0,upload/* formatUploadTitle */.$O)(u)} ${u.size > 0 ? (0,filesize/* fileSize */.j)(u.size) : ""}`,
                    value: u.id,
                    upload: u,
                };
                return val;
            });
        }
        let uploadValue = (0,index_all/* findWhere */._e)(uploadOptions, { value: pickedUploadId });
        return (react.createElement(react.Fragment, null,
            react.createElement(WideBox, null,
                react.createElement(boxes/* BoxInner */.BV, null,
                    react.createElement(StandardGameCover/* default */.ZP, { game: game }),
                    react.createElement(SortsAndFilters/* FilterSpacer */.dz, null),
                    react.createElement(StandardGameDesc/* default */.Z, { game: game }),
                    react.createElement(SortsAndFilters/* FilterSpacer */.dz, null))),
            react.createElement(SelectGroup, null,
                react.createElement(SelectHeader, null, (0,t.T)((0,t._)("plan_install.select_upload"))),
                react.createElement(SimpleSelect/* default */.Z, { onChange: this.onUploadChange, value: uploadValue, options: uploadOptions, OptionComponent: UploadOptionComponent, isLoading: busy })),
            react.createElement(SelectGroup, null,
                react.createElement(SelectHeader, null, (0,t.T)((0,t._)("plan_install.select_install_location"))),
                react.createElement(SimpleSelect/* default */.Z, { onChange: this.onInstallLocationChange, value: locationValue, options: locationOptions, OptionComponent: InstallLocationOptionComponent })),
            react.createElement(Filler/* default */.Z, null),
            busy
                ? this.renderBusy()
                : error
                    ? this.renderError()
                    : this.renderSizes(),
            react.createElement(Filler/* default */.Z, null),
            react.createElement(modal_styles/* ModalButtons */.Z, null,
                react.createElement(Button/* default */.Z, { onClick: this.onCancel }, (0,t.T)(["prompt.action.cancel"])),
                react.createElement(Filler/* default */.Z, null),
                react.createElement(Button/* default */.Z, { disabled: !canInstall, icon: "install", primary: true, onClick: this.onInstall, id: canInstall ? "modal-install-now" : null }, (0,t.T)(["grid.item.install"])))));
    }
    renderError() {
        const { error } = this.state;
        return (react.createElement(ErrorContainer, null,
            react.createElement(ErrorParagraph, null,
                react.createElement(Icon/* default */.Z, { icon: "error" }),
                " ",
                (0,t.T)((0,errors/* formatError */.Z)(error))),
            react.createElement(ErrorButtons, null,
                react.createElement(Button/* default */.Z, { label: (0,t.T)(["grid.item.view_details"]), onClick: this.onShowError }))));
    }
    renderBusy() {
        return (react.createElement(butlerCaller/* LoadingStateDiv */.K_, null,
            (0,t.T)((0,t._)("plan_install.computing_space_requirements")),
            react.createElement(SortsAndFilters/* FilterSpacer */.dz, null),
            react.createElement(Floater/* default */.Z, null)));
    }
    renderSizes() {
        const { info, pickedInstallLocationId, installLocations } = this.state;
        if (!info) {
            return null;
        }
        const installLocation = (0,index_all/* findWhere */._e)(installLocations, {
            id: pickedInstallLocationId,
        });
        if (!installLocation) {
            return null;
        }
        const requiredSpace = info ? info.diskUsage.neededFreeSpace : -1;
        const freeSpace = installLocation.sizeInfo.freeSize;
        const haveEnoughSpace = requiredSpace <= freeSpace;
        return (react.createElement(SizeTable, null,
            react.createElement("tbody", null,
                react.createElement("tr", null,
                    react.createElement("td", { className: "desc" }, (0,t.T)((0,t._)("plan_install.disk_space_required"))),
                    react.createElement("td", null,
                        react.createElement("strong", null, requiredSpace > 0 ? (0,filesize/* fileSize */.j)(requiredSpace) : "?"))),
                react.createElement("tr", null,
                    react.createElement("td", { className: "desc" }, (0,t.T)((0,t._)("plan_install.disk_space_available"))),
                    react.createElement("td", { className: classnames_default()({ low: !haveEnoughSpace }) },
                        react.createElement("strong", null, (0,filesize/* fileSize */.j)(freeSpace)),
                        haveEnoughSpace ? (react.createElement(DiskSpaceIcon, { icon: "checkmark" })) : (react.createElement(DiskSpaceIcon, { icon: "warning" })))))));
    }
    close() {
        const { wind, id } = this.props.modal;
        const { dispatch } = this.props;
        dispatch(actions/* actions */.N.closeModal({ wind, id }));
    }
    componentDidMount() {
        this.loadInstallLocations();
        const { uploadId } = this.props.modal.widgetParams;
        this.pickUpload(uploadId);
    }
    loadInstallLocations() {
        (0,doAsync/* doAsync */.R)(async () => {
            const { defaultInstallLocation } = this.props;
            const { installLocations } = await (0,rcall/* rcall */.v)(messages/* InstallLocationsList */.kx, {});
            const defaultRecord = (0,index_all/* findWhere */._e)(installLocations, {
                id: defaultInstallLocation,
            });
            this.setState({
                stage: PlanStage.Planning,
                installLocations,
                pickedInstallLocationId: defaultRecord
                    ? defaultRecord.id
                    : installLocations[0].id,
            });
        });
    }
    pickUpload(uploadId) {
        (0,doAsync/* doAsync */.R)(async () => {
            try {
                const { gameId } = this.state;
                const logger = (0,common_logger/* recordingLogger */.CI)(renderer_logger/* rendererLogger */.X);
                // investigate
                const res = await (0,rcall/* rcall */.v)(messages/* InstallPlan */.zi, { gameId, uploadId }, [
                    (0,bridge/* hookLogging */.mK)(logger),
                ]);
                this.setState({
                    stage: PlanStage.Planning,
                    game: res.game,
                    uploads: res.uploads,
                    pickedUploadId: res.info ? res.info.upload.id : null,
                    info: res.info,
                    busy: false,
                    error: res.info && res.info.error
                        ? (0,errors/* getInstallPlanInfoError */.dK)(res.info)
                        : null,
                    log: logger.getLog(),
                });
            }
            catch (e) {
                this.setState({
                    busy: false,
                    error: e,
                });
            }
        });
    }
};
PlanInstall = (0,tslib_es6/* __decorate */.gn)([
    watching/* default */.Z
], PlanInstall);
/* harmony default export */ const modal_widgets_PlanInstall = ((0,injectIntl/* default */.ZP)((0,hook/* hook */.z)((map) => ({
    defaultInstallLocation: map((rs) => rs.preferences.defaultInstallLocation),
}))(PlanInstall)));


/***/ }),

/***/ 5871:
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   U: () => (/* binding */ ModalWidgetDiv)
/* harmony export */ });
/* harmony import */ var renderer_styles__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(5836);

const ModalWidgetDiv = renderer_styles__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .ZP.div `
  padding: 20px;
  flex-grow: 1;
  overflow-y: auto;

  input[type="number"],
  input[type="text"],
  input[type="password"] {
    ${renderer_styles__WEBPACK_IMPORTED_MODULE_0__/* .heavyInput */ .C1};
    width: 100%;
  }

  input[type="number"] {
    &::-webkit-inner-spin-button,
    &::-webkit-outer-spin-button {
      -webkit-appearance: none;
      margin: 0;
    }
  }

  strong {
    font-weight: bold;
  }

  p {
    line-height: 1.4;
    margin: 8px 0;
  }
`;


/***/ }),

/***/ 1625:
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   BV: () => (/* binding */ BoxInner),
/* harmony export */   xu: () => (/* binding */ Box)
/* harmony export */ });
/* unused harmony exports BaseBox, BoxSingle */
/* harmony import */ var renderer_styles__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(5836);

const BaseBox = renderer_styles__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .ZP.div `
  margin: 1em auto;
  line-height: 1.6;
`;
const Box = renderer_styles__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .ZP.div `
  ${renderer_styles__WEBPACK_IMPORTED_MODULE_0__/* .boxy */ .wN};
  max-width: 1200px;

  margin: 1em auto;
  line-height: 1.6;
`;
const BoxSingle = renderer_styles__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .ZP.div `
  ${renderer_styles__WEBPACK_IMPORTED_MODULE_0__/* .boxy */ .wN};

  margin: 1em auto;
  line-height: 1.6;
`;
const BoxInner = renderer_styles__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .ZP.div `
  width: 100%;
  display: flex;
  flex-direction: row;
  align-items: center;
`;


/***/ }),

/***/ 7128:
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   Ni: () => (/* binding */ FilterOptionButton),
/* harmony export */   Zk: () => (/* binding */ FilterOptionIcon),
/* harmony export */   dz: () => (/* binding */ FilterSpacer),
/* harmony export */   e_: () => (/* binding */ FilterGroup),
/* harmony export */   gY: () => (/* binding */ SortsAndFilters),
/* harmony export */   zR: () => (/* binding */ FilterOptionLink)
/* harmony export */ });
/* harmony import */ var renderer_basics_FiltersContainer__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(4987);
/* harmony import */ var renderer_basics_Icon__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(4198);
/* harmony import */ var renderer_styles__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(5836);



const SortsAndFilters = (0,renderer_styles__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .ZP)((0,renderer_basics_FiltersContainer__WEBPACK_IMPORTED_MODULE_0__/* .FiltersContainerDiv */ .vN)) `
  display: flex;
  justify-content: center;
  flex-flow: row wrap;
  height: auto;

  padding: 0.4em 0.6em;
  font-weight: normal;
`;
const FilterGroup = renderer_styles__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .ZP.div `
  margin: 0.5em 0;
  display: flex;
  flex-flow: row wrap;
`;
// const inactiveBg = `linear-gradient(to top,hsla(355, 43%, 25%, 1),hsla(355, 43%, 17%, 1))`;
// const activeBg = `linear-gradient(to top, hsla(355, 43%, 50%, 1), hsla(355, 43%, 37%, 1));`;
const inactiveBg = `linear-gradient(to top,hsla(355, 43%, 17%, 1),hsla(355, 43%, 11%, 1))`;
const activeBg = `linear-gradient(to top, hsla(355, 43%, 33%, 1), hsla(355, 43%, 22%, 1));`;
const borderColor = `#843442`;
const borderRadius = `4px`;
const optionButtonLike = (0,renderer_styles__WEBPACK_IMPORTED_MODULE_2__/* .css */ .iv) `
  display: flex;
  flex-flow: row;
  align-items: center;

  background: ${inactiveBg};
  padding: 0.5em 1em;
  margin: 0;
  border: 1px solid ${borderColor};
  border-left: none;
  color: ${(props) => props.theme.baseText};
  transition: all 0.4s;

  &:first-child {
    border-radius: ${borderRadius} 0 0 ${borderRadius};
    border-left: 1px solid ${borderColor};
  }

  &:last-child {
    border-radius: 0 ${borderRadius} ${borderRadius} 0;
  }

  &:first-child:last-child {
    border-radius: ${borderRadius};
  }

  &.active {
    background: ${activeBg};
    color: ${(props) => props.theme.baseText};
  }

  &:hover {
    cursor: pointer;
  }
`;
const FilterOptionLink = renderer_styles__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .ZP.a `
  ${optionButtonLike};

  &.disabled {
    pointer-events: none;
    opacity: 0.4;
  }
`;
const FilterOptionButton = renderer_styles__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .ZP.div `
  ${optionButtonLike};
`;
const FilterOptionIcon = (0,renderer_styles__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .ZP)((0,renderer_basics_Icon__WEBPACK_IMPORTED_MODULE_1__/* ["default"] */ .Z)) `
  margin-right: 0.5em;
  font-size: 80%;

  opacity: 1;
  &.inactive {
    opacity: 0.2;
  }
`;
const FilterSpacer = renderer_styles__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .ZP.div `
  width: 24px;
  flex-shrink: 0;
`;


/***/ }),

/***/ 5231:
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   Z: () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony import */ var common_util_navigation__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(9471);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(7294);
/* harmony import */ var renderer_basics_Filler__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(4333);
/* harmony import */ var renderer_basics_PlatformIcons__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(3043);
/* harmony import */ var renderer_pages_PageStyles_games__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(465);
/* harmony import */ var renderer_t__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(9080);






const StandardGameDesc = ({ game, children, }) => {
    if (!game) {
        return (react__WEBPACK_IMPORTED_MODULE_0__.createElement(renderer_pages_PageStyles_games__WEBPACK_IMPORTED_MODULE_3__/* .TitleBox */ .kS, null,
            react__WEBPACK_IMPORTED_MODULE_0__.createElement(renderer_pages_PageStyles_games__WEBPACK_IMPORTED_MODULE_3__/* .Title */ .Dx, null)));
    }
    return (react__WEBPACK_IMPORTED_MODULE_0__.createElement(renderer_pages_PageStyles_games__WEBPACK_IMPORTED_MODULE_3__/* .TitleBox */ .kS, null,
        react__WEBPACK_IMPORTED_MODULE_0__.createElement("a", { href: (0,common_util_navigation__WEBPACK_IMPORTED_MODULE_5__/* .urlForGame */ .OH)(game.id), className: "gamedesc--titlelink" },
            react__WEBPACK_IMPORTED_MODULE_0__.createElement(renderer_pages_PageStyles_games__WEBPACK_IMPORTED_MODULE_3__/* .Title */ .Dx, null,
                react__WEBPACK_IMPORTED_MODULE_0__.createElement("div", { className: "gamedesc--title" }, game.title),
                children)),
        react__WEBPACK_IMPORTED_MODULE_0__.createElement("div", null, game.shortText),
        react__WEBPACK_IMPORTED_MODULE_0__.createElement(renderer_basics_Filler__WEBPACK_IMPORTED_MODULE_1__/* ["default"] */ .Z, null),
        react__WEBPACK_IMPORTED_MODULE_0__.createElement("div", null,
            renderClassification(game.classification),
            react__WEBPACK_IMPORTED_MODULE_0__.createElement(renderer_basics_PlatformIcons__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .Z, { target: game, before: () => react__WEBPACK_IMPORTED_MODULE_0__.createElement(react__WEBPACK_IMPORTED_MODULE_0__.Fragment, null, "\u00A0\u00A0") }))));
};
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (StandardGameDesc);
function renderClassification(classification) {
    let label = [`usage_stats.description.${classification}`];
    return react__WEBPACK_IMPORTED_MODULE_0__.createElement(react__WEBPACK_IMPORTED_MODULE_0__.Fragment, null, (0,renderer_t__WEBPACK_IMPORTED_MODULE_4__.T)(label));
}


/***/ })

}]);
//# sourceMappingURL=135.chunk.js.map