"use strict";
(self["webpackChunkLIB"] = self["webpackChunkLIB"] || []).push([[301],{

/***/ 992:
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   Nd: () => (/* binding */ getRpcErrorData),
/* harmony export */   SS: () => (/* binding */ isInternalError),
/* harmony export */   dt: () => (/* binding */ getErrorStack),
/* harmony export */   mg: () => (/* binding */ asRequestError)
/* harmony export */ });
/* unused harmony export mergeLogAndError */
/* harmony import */ var common_logger__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(8976);
/* harmony import */ var common_format_datetime__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(1061);


function asRequestError(e) {
    const re = e;
    if (re.rpcError) {
        return e;
    }
    return null;
}
function getRpcErrorData(e) {
    const re = asRequestError(e);
    if (re && re.rpcError && re.rpcError.data) {
        return re.rpcError.data;
    }
    return null;
}
function isInternalError(e) {
    const re = asRequestError(e);
    if (!re) {
        return true;
    }
    if (re.rpcError.code < 0) {
        return true;
    }
    return false;
}
function getErrorStack(e) {
    if (!e) {
        return "Unknown error";
    }
    let errorStack = e.stack;
    const re = asRequestError(e);
    if (re) {
        const ed = getRpcErrorData(e);
        if (ed && ed.stack) {
            // use golang stack if available
            errorStack = ed.stack;
        }
        else if (re.message) {
            // or just message
            errorStack = re.message;
        }
    }
    return errorStack;
}
function mergeLogAndError(log, e) {
    let formattedLog = "";
    if (log) {
        let lines = log.split("\n");
        for (let line of lines) {
            line = line.trim();
            let fallback = false;
            try {
                const obj = JSON.parse(line);
                if (obj.msg) {
                    let date = formatDate(new Date(obj.time), "en-US", DATE_FORMAT);
                    let level = levels[obj.level];
                    let { msg } = obj;
                    formattedLog += `${date} [${level}] ${msg}\n`;
                }
                else {
                    fallback = true;
                }
            }
            catch (e) {
                fallback = true;
            }
            if (fallback) {
                formattedLog += `${line}\n`;
            }
        }
    }
    return `${formattedLog}\n\nError stack:\n${getErrorStack(e)}\n`;
}


/***/ }),

/***/ 8383:
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   eE: () => (/* binding */ isNetworkError)
/* harmony export */ });
/* unused harmony exports RequestError, RequestTimeout, RequestAborted, RequestFormattingFailure, RequestParsingFailure */
/* harmony import */ var common_butlerd_errors__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(992);
/* harmony import */ var common_butlerd_messages__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(4713);


/**
 * Returns true if this is a network error
 */
function isNetworkError(e) {
    // this operates under the assumption that:
    //   * all our internal network errors should start with "err::"
    //   * all of chrome's already do
    //   * we transform fetch's into err:: variants.
    // we coerce e.message into a string on the off chance that it's not defined
    // or not a string.
    const isJavaScriptNetworkError = e && ("" + e.message).indexOf("net::") === 0;
    if (isJavaScriptNetworkError) {
        return true;
    }
    const re = (0,common_butlerd_errors__WEBPACK_IMPORTED_MODULE_0__/* .asRequestError */ .mg)(e);
    if (re) {
        if (re.rpcError.code === common_butlerd_messages__WEBPACK_IMPORTED_MODULE_1__/* .Code */ .EK.NetworkDisconnected) {
            return true;
        }
    }
    return false;
}
class RequestError extends (/* unused pure expression or super */ null && (Error)) {
    constructor(message) {
        super(message.indexOf("net::") == 0 ? message : "net::REQUEST_ERROR::");
    }
}
class RequestTimeout extends (/* unused pure expression or super */ null && (RequestError)) {
    constructor() {
        super("TIMED_OUT");
    }
}
class RequestAborted extends (/* unused pure expression or super */ null && (RequestError)) {
    constructor() {
        super("ABORTED");
    }
}
class RequestFormattingFailure extends (/* unused pure expression or super */ null && (RequestError)) {
    constructor(message) {
        super("FORMATTING_FAILURE: " + message);
    }
}
class RequestParsingFailure extends (/* unused pure expression or super */ null && (RequestError)) {
    constructor(message) {
        super("PARSING_FAILURE: " + message);
    }
}


/***/ }),

/***/ 7883:
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   Z: () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(7294);
/* harmony import */ var renderer_basics_Button__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(6025);
/* harmony import */ var renderer_basics_Icon__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(4198);
/* harmony import */ var renderer_styles__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(5836);
/* harmony import */ var renderer_t__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(9080);





const EmptyStateDiv = renderer_styles__WEBPACK_IMPORTED_MODULE_3__/* ["default"] */ .ZP.div `
  color: ${(props) => props.theme.secondaryText};
  width: 100%;
  text-align: center;
  margin: 60px 0;

  .leader {
    display: inline-block;
    font-size: 170px;
    margin-bottom: 20px;
  }

  h1 {
    font-size: ${(props) => props.theme.fontSizes.enormous};
    font-weight: bold;
    margin-bottom: 10px;
  }

  h2 {
    font-size: ${(props) => props.theme.fontSizes.huge};
  }
`;
const ButtonContainer = renderer_styles__WEBPACK_IMPORTED_MODULE_3__/* ["default"] */ .ZP.div `
  margin: 20px;
  display: inline-block;
`;
const EmptyStateContainer = renderer_styles__WEBPACK_IMPORTED_MODULE_3__/* ["default"] */ .ZP.div `
  display: flex;
  width: 100%;
  height: 100%;
  align-items: center;
  overflow: hidden;
`;
class EmptyState extends react__WEBPACK_IMPORTED_MODULE_0__.PureComponent {
    render() {
        const { bigText, smallText, icon, buttonIcon, buttonText, buttonAction, componentAction, className, } = this.props;
        return (react__WEBPACK_IMPORTED_MODULE_0__.createElement(EmptyStateContainer, null,
            react__WEBPACK_IMPORTED_MODULE_0__.createElement(EmptyStateDiv, { className: className },
                react__WEBPACK_IMPORTED_MODULE_0__.createElement(renderer_basics_Icon__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .Z, { icon: icon, className: "leader" }),
                react__WEBPACK_IMPORTED_MODULE_0__.createElement("h1", null, (0,renderer_t__WEBPACK_IMPORTED_MODULE_4__.T)(bigText)),
                smallText ? react__WEBPACK_IMPORTED_MODULE_0__.createElement("h2", null, (0,renderer_t__WEBPACK_IMPORTED_MODULE_4__.T)(smallText)) : null,
                componentAction,
                buttonAction ? (react__WEBPACK_IMPORTED_MODULE_0__.createElement(react__WEBPACK_IMPORTED_MODULE_0__.Fragment, null,
                    react__WEBPACK_IMPORTED_MODULE_0__.createElement(ButtonContainer, null,
                        react__WEBPACK_IMPORTED_MODULE_0__.createElement(renderer_basics_Button__WEBPACK_IMPORTED_MODULE_1__/* ["default"] */ .Z, { icon: buttonIcon, primary: true, onClick: buttonAction }, (0,renderer_t__WEBPACK_IMPORTED_MODULE_4__.T)(buttonText))))) : null)));
    }
}
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (EmptyState);


/***/ }),

/***/ 36:
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   Z: () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(7294);
/* harmony import */ var common_helpers_get_game_status__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(945);
/* harmony import */ var renderer_hocs_hook__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(2263);



class GameStatusGetter extends react__WEBPACK_IMPORTED_MODULE_0__.PureComponent {
    render() {
        const { status, render } = this.props;
        return render(status);
    }
}
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ((0,renderer_hocs_hook__WEBPACK_IMPORTED_MODULE_2__/* .hookWithProps */ .h)(GameStatusGetter)((map) => ({
    status: map((rs, props) => (0,common_helpers_get_game_status__WEBPACK_IMPORTED_MODULE_1__/* ["default"] */ .ZP)(rs, props.game, props.caveId)),
}))(GameStatusGetter));


/***/ }),

/***/ 485:
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   Z: () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(4184);
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(classnames__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var common_actions__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(2448);
/* harmony import */ var common_helpers_get_game_status__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(945);
/* harmony import */ var common_util_action_for_game__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(1829);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(7294);
/* harmony import */ var renderer_basics_Button__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(6025);
/* harmony import */ var renderer_basics_Icon__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(4198);
/* harmony import */ var renderer_basics_IconButton__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(5391);
/* harmony import */ var renderer_basics_LoadingCircle__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(6785);
/* harmony import */ var renderer_t__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(9080);
/* harmony import */ var renderer_hocs_hook__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(2263);
/* harmony import */ var common_helpers_secret_click__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(4843);












class MainAction extends react__WEBPACK_IMPORTED_MODULE_4__.PureComponent {
    constructor() {
        super(...arguments);
        this.onClick = (e) => {
            e.stopPropagation();
            const { dispatch, game, status } = this.props;
            const { operation, update, cave, access } = status;
            if ((0,common_helpers_secret_click__WEBPACK_IMPORTED_MODULE_11__/* .isSecretClick */ .C)(e)) {
                if (cave) {
                    dispatch(common_actions__WEBPACK_IMPORTED_MODULE_1__/* .actions */ .N.viewCaveDetails({ caveId: cave.id }));
                }
                return;
            }
            if (operation) {
                if (operation.type === common_helpers_get_game_status__WEBPACK_IMPORTED_MODULE_2__/* .OperationType */ .C8.Download) {
                    dispatch(common_actions__WEBPACK_IMPORTED_MODULE_1__/* .actions */ .N.navigate({ wind: "root", url: "itch://downloads" }));
                }
                else if (operation.type === common_helpers_get_game_status__WEBPACK_IMPORTED_MODULE_2__/* .OperationType */ .C8.Task) {
                    if (operation.name === "launch") {
                        dispatch(common_actions__WEBPACK_IMPORTED_MODULE_1__/* .actions */ .N.forceCloseGameRequest({ game }));
                    }
                }
            }
            else if (cave) {
                if (update) {
                    dispatch(common_actions__WEBPACK_IMPORTED_MODULE_1__/* .actions */ .N.showGameUpdate({ update }));
                }
                else {
                    dispatch(common_actions__WEBPACK_IMPORTED_MODULE_1__/* .actions */ .N.queueGame({ game }));
                }
            }
            else {
                if (access === common_helpers_get_game_status__WEBPACK_IMPORTED_MODULE_2__/* .Access */ .Nv.None) {
                    dispatch(common_actions__WEBPACK_IMPORTED_MODULE_1__/* .actions */ .N.initiatePurchase({ game }));
                }
                else {
                    dispatch(common_actions__WEBPACK_IMPORTED_MODULE_1__/* .actions */ .N.queueGame({ game }));
                }
            }
        };
    }
    render() {
        const { wide } = this.props;
        const { cave, access, operation, update } = this.props.status;
        let translucent = false;
        let iconComponent;
        let icon;
        let label;
        let primary = false;
        if (operation) {
            const { type, progress } = operation;
            translucent = true;
            if (operation.paused) {
                iconComponent = react__WEBPACK_IMPORTED_MODULE_4__.createElement(renderer_basics_Icon__WEBPACK_IMPORTED_MODULE_6__/* ["default"] */ .Z, { icon: "stopwatch" });
            }
            else if (!operation.active) {
                iconComponent = react__WEBPACK_IMPORTED_MODULE_4__.createElement(renderer_basics_Icon__WEBPACK_IMPORTED_MODULE_6__/* ["default"] */ .Z, { icon: "stopwatch" });
            }
            else {
                iconComponent = (react__WEBPACK_IMPORTED_MODULE_4__.createElement(renderer_basics_LoadingCircle__WEBPACK_IMPORTED_MODULE_8__/* ["default"] */ .Z, { bare: true, wide: wide, progress: progress > 0 ? progress : 0.1 }));
            }
            if (type === common_helpers_get_game_status__WEBPACK_IMPORTED_MODULE_2__/* .OperationType */ .C8.Download) {
                if (operation.paused) {
                    label = ["grid.item.downloads_paused"];
                }
                else if (operation.active) {
                    label = ["grid.item.installing"];
                }
                else {
                    label = ["grid.item.queued"];
                }
            }
            else if (type === common_helpers_get_game_status__WEBPACK_IMPORTED_MODULE_2__/* .OperationType */ .C8.Task) {
                const { name, stage } = operation;
                if (name === "launch") {
                    if (stage === "prepare") {
                        label = ["grid.item.running.prepare"];
                    }
                    else if (stage === "clean") {
                        label = ["grid.item.running.clean"];
                    }
                    else {
                        label = ["grid.item.running"];
                    }
                }
                else if (name === "uninstall") {
                    label = ["grid.item.uninstalling"];
                }
                else if (name === "install-queue") {
                    label = ["grid.item.queueing"];
                }
                else {
                    label = ["grid.item.installing"];
                }
            }
        }
        else if (cave) {
            if (update) {
                label = ["grid.item.update"];
                icon = "star";
            }
            else {
                const action = (0,common_util_action_for_game__WEBPACK_IMPORTED_MODULE_3__/* .actionForGame */ .x)(this.props.game, cave);
                label = [`grid.item.${action}`];
                if (action === "open") {
                    icon = "folder-open";
                }
                else {
                    icon = "play2";
                }
                primary = true;
            }
        }
        else {
            if (access === common_helpers_get_game_status__WEBPACK_IMPORTED_MODULE_2__/* .Access */ .Nv.Demo || access === common_helpers_get_game_status__WEBPACK_IMPORTED_MODULE_2__/* .Access */ .Nv.Press) {
                label = ["grid.item.review"];
                icon = "install";
            }
            else if (access === common_helpers_get_game_status__WEBPACK_IMPORTED_MODULE_2__/* .Access */ .Nv.Pwyw ||
                access === common_helpers_get_game_status__WEBPACK_IMPORTED_MODULE_2__/* .Access */ .Nv.Free ||
                access === common_helpers_get_game_status__WEBPACK_IMPORTED_MODULE_2__/* .Access */ .Nv.Key ||
                access === common_helpers_get_game_status__WEBPACK_IMPORTED_MODULE_2__/* .Access */ .Nv.Edit) {
                label = ["grid.item.install"];
                icon = "install";
            }
            else {
                label = ["grid.item.buy_now"];
                icon = "shopping_cart";
            }
        }
        if (!label) {
            return null;
        }
        const { iconOnly, className } = this.props;
        if (iconOnly) {
            if (!iconComponent) {
                if (icon) {
                    iconComponent = react__WEBPACK_IMPORTED_MODULE_4__.createElement(renderer_basics_Icon__WEBPACK_IMPORTED_MODULE_6__/* ["default"] */ .Z, { icon: icon });
                }
            }
            return (react__WEBPACK_IMPORTED_MODULE_4__.createElement(renderer_basics_IconButton__WEBPACK_IMPORTED_MODULE_7__/* ["default"] */ .Z, { onClick: this.onClick, className: classnames__WEBPACK_IMPORTED_MODULE_0___default()(className, "main-action"), "data-game-id": this.props.game.id, icon: iconComponent, hint: label, hintPosition: "left" }));
        }
        return (react__WEBPACK_IMPORTED_MODULE_4__.createElement(renderer_basics_Button__WEBPACK_IMPORTED_MODULE_5__/* ["default"] */ .Z, { onClick: this.onClick, className: classnames__WEBPACK_IMPORTED_MODULE_0___default()(className, "main-action"), wide: wide, translucent: translucent, iconComponent: iconComponent, label: (0,renderer_t__WEBPACK_IMPORTED_MODULE_9__.T)(label), primary: primary, "data-game-id": this.props.game.id }));
    }
}
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ((0,renderer_hocs_hook__WEBPACK_IMPORTED_MODULE_10__/* .hook */ .z)()(MainAction));


/***/ }),

/***/ 1625:
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   BV: () => (/* binding */ BoxInner),
/* harmony export */   xu: () => (/* binding */ Box)
/* harmony export */ });
/* unused harmony exports BaseBox, BoxSingle */
/* harmony import */ var renderer_styles__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(5836);

const BaseBox = renderer_styles__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .ZP.div `
  margin: 1em auto;
  line-height: 1.6;
`;
const Box = renderer_styles__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .ZP.div `
  ${renderer_styles__WEBPACK_IMPORTED_MODULE_0__/* .boxy */ .wN};
  max-width: 1200px;

  margin: 1em auto;
  line-height: 1.6;
`;
const BoxSingle = renderer_styles__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .ZP.div `
  ${renderer_styles__WEBPACK_IMPORTED_MODULE_0__/* .boxy */ .wN};

  margin: 1em auto;
  line-height: 1.6;
`;
const BoxInner = renderer_styles__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .ZP.div `
  width: 100%;
  display: flex;
  flex-direction: row;
  align-items: center;
`;


/***/ }),

/***/ 6797:
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   Z: () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony import */ var renderer_styles__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(5836);

/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (renderer_styles__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .ZP.div `
  flex-grow: 1;
  overflow-y: auto;
  padding: 0 12px;

  user-select: none;

  /* this scrolls, so we want it to have its own layer */
  will-change: transform;
`);


/***/ }),

/***/ 1945:
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   Y: () => (/* binding */ SortOption)
/* harmony export */ });
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(4184);
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(classnames__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var common_util_navigation__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(9471);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(7294);
/* harmony import */ var renderer_hocs_hook__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(2263);
/* harmony import */ var renderer_hocs_tab_utils__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(2250);
/* harmony import */ var renderer_hocs_withTab__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(2521);
/* harmony import */ var renderer_pages_common_SortsAndFilters__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(7128);
/* harmony import */ var renderer_t__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(9080);








const SortOptionBase = (props) => {
    const { url, active, reverse, sortBy, label } = props;
    let href;
    let baseClass = `sortby--${sortBy}`;
    if (!active) {
        baseClass = `${baseClass}--default`;
        href = (0,renderer_hocs_tab_utils__WEBPACK_IMPORTED_MODULE_3__/* .urlWithParams */ .Iq)(url, { sortBy, sortDir: "default" });
    }
    else {
        if (!reverse) {
            baseClass = `${baseClass}--reverse`;
            href = (0,renderer_hocs_tab_utils__WEBPACK_IMPORTED_MODULE_3__/* .urlWithParams */ .Iq)(url, { sortBy, sortDir: "reverse" });
        }
        else {
            baseClass = `${baseClass}--disable`;
            href = (0,renderer_hocs_tab_utils__WEBPACK_IMPORTED_MODULE_3__/* .urlWithParams */ .Iq)(url, { sortBy: undefined, sortDir: undefined });
        }
    }
    return (react__WEBPACK_IMPORTED_MODULE_1__.createElement(renderer_pages_common_SortsAndFilters__WEBPACK_IMPORTED_MODULE_5__/* .FilterOptionLink */ .zR, { target: "_replace", href: href, className: classnames__WEBPACK_IMPORTED_MODULE_0___default()(baseClass, { active }) },
        react__WEBPACK_IMPORTED_MODULE_1__.createElement(renderer_pages_common_SortsAndFilters__WEBPACK_IMPORTED_MODULE_5__/* .FilterOptionIcon */ .Zk, { className: classnames__WEBPACK_IMPORTED_MODULE_0___default()({ inactive: !active }), icon: active && reverse ? "sort-amount-desc" : "sort-amount-asc" }),
        (0,renderer_t__WEBPACK_IMPORTED_MODULE_6__.T)(label)));
};
const hooked = (0,renderer_hocs_hook__WEBPACK_IMPORTED_MODULE_2__/* .hookWithProps */ .h)(SortOptionBase)((map) => ({
    url: map((rs, props) => (0,common_util_navigation__WEBPACK_IMPORTED_MODULE_7__/* .ambientTab */ .mB)(rs, props).location.url),
    active: map((rs, props) => (0,common_util_navigation__WEBPACK_IMPORTED_MODULE_7__/* .ambientTab */ .mB)(rs, props).location.query.sortBy === props.sortBy),
    reverse: map((rs, props) => (0,common_util_navigation__WEBPACK_IMPORTED_MODULE_7__/* .ambientTab */ .mB)(rs, props).location.query.sortDir === "reverse"),
}))(SortOptionBase);
const SortOption = (0,renderer_hocs_withTab__WEBPACK_IMPORTED_MODULE_4__/* .withTab */ .D1)(hooked);


/***/ }),

/***/ 7128:
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   Ni: () => (/* binding */ FilterOptionButton),
/* harmony export */   Zk: () => (/* binding */ FilterOptionIcon),
/* harmony export */   dz: () => (/* binding */ FilterSpacer),
/* harmony export */   e_: () => (/* binding */ FilterGroup),
/* harmony export */   gY: () => (/* binding */ SortsAndFilters),
/* harmony export */   zR: () => (/* binding */ FilterOptionLink)
/* harmony export */ });
/* harmony import */ var renderer_basics_FiltersContainer__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(4987);
/* harmony import */ var renderer_basics_Icon__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(4198);
/* harmony import */ var renderer_styles__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(5836);



const SortsAndFilters = (0,renderer_styles__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .ZP)((0,renderer_basics_FiltersContainer__WEBPACK_IMPORTED_MODULE_0__/* .FiltersContainerDiv */ .vN)) `
  display: flex;
  justify-content: center;
  flex-flow: row wrap;
  height: auto;

  padding: 0.4em 0.6em;
  font-weight: normal;
`;
const FilterGroup = renderer_styles__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .ZP.div `
  margin: 0.5em 0;
  display: flex;
  flex-flow: row wrap;
`;
// const inactiveBg = `linear-gradient(to top,hsla(355, 43%, 25%, 1),hsla(355, 43%, 17%, 1))`;
// const activeBg = `linear-gradient(to top, hsla(355, 43%, 50%, 1), hsla(355, 43%, 37%, 1));`;
const inactiveBg = `linear-gradient(to top,hsla(355, 43%, 17%, 1),hsla(355, 43%, 11%, 1))`;
const activeBg = `linear-gradient(to top, hsla(355, 43%, 33%, 1), hsla(355, 43%, 22%, 1));`;
const borderColor = `#843442`;
const borderRadius = `4px`;
const optionButtonLike = (0,renderer_styles__WEBPACK_IMPORTED_MODULE_2__/* .css */ .iv) `
  display: flex;
  flex-flow: row;
  align-items: center;

  background: ${inactiveBg};
  padding: 0.5em 1em;
  margin: 0;
  border: 1px solid ${borderColor};
  border-left: none;
  color: ${(props) => props.theme.baseText};
  transition: all 0.4s;

  &:first-child {
    border-radius: ${borderRadius} 0 0 ${borderRadius};
    border-left: 1px solid ${borderColor};
  }

  &:last-child {
    border-radius: 0 ${borderRadius} ${borderRadius} 0;
  }

  &:first-child:last-child {
    border-radius: ${borderRadius};
  }

  &.active {
    background: ${activeBg};
    color: ${(props) => props.theme.baseText};
  }

  &:hover {
    cursor: pointer;
  }
`;
const FilterOptionLink = renderer_styles__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .ZP.a `
  ${optionButtonLike};

  &.disabled {
    pointer-events: none;
    opacity: 0.4;
  }
`;
const FilterOptionButton = renderer_styles__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .ZP.div `
  ${optionButtonLike};
`;
const FilterOptionIcon = (0,renderer_styles__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .ZP)((0,renderer_basics_Icon__WEBPACK_IMPORTED_MODULE_1__/* ["default"] */ .Z)) `
  margin-right: 0.5em;
  font-size: 80%;

  opacity: 1;
  &.inactive {
    opacity: 0.2;
  }
`;
const FilterSpacer = renderer_styles__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .ZP.div `
  width: 24px;
  flex-shrink: 0;
`;


/***/ }),

/***/ 5231:
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   Z: () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony import */ var common_util_navigation__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(9471);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(7294);
/* harmony import */ var renderer_basics_Filler__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(4333);
/* harmony import */ var renderer_basics_PlatformIcons__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(3043);
/* harmony import */ var renderer_pages_PageStyles_games__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(465);
/* harmony import */ var renderer_t__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(9080);






const StandardGameDesc = ({ game, children, }) => {
    if (!game) {
        return (react__WEBPACK_IMPORTED_MODULE_0__.createElement(renderer_pages_PageStyles_games__WEBPACK_IMPORTED_MODULE_3__/* .TitleBox */ .kS, null,
            react__WEBPACK_IMPORTED_MODULE_0__.createElement(renderer_pages_PageStyles_games__WEBPACK_IMPORTED_MODULE_3__/* .Title */ .Dx, null)));
    }
    return (react__WEBPACK_IMPORTED_MODULE_0__.createElement(renderer_pages_PageStyles_games__WEBPACK_IMPORTED_MODULE_3__/* .TitleBox */ .kS, null,
        react__WEBPACK_IMPORTED_MODULE_0__.createElement("a", { href: (0,common_util_navigation__WEBPACK_IMPORTED_MODULE_5__/* .urlForGame */ .OH)(game.id), className: "gamedesc--titlelink" },
            react__WEBPACK_IMPORTED_MODULE_0__.createElement(renderer_pages_PageStyles_games__WEBPACK_IMPORTED_MODULE_3__/* .Title */ .Dx, null,
                react__WEBPACK_IMPORTED_MODULE_0__.createElement("div", { className: "gamedesc--title" }, game.title),
                children)),
        react__WEBPACK_IMPORTED_MODULE_0__.createElement("div", null, game.shortText),
        react__WEBPACK_IMPORTED_MODULE_0__.createElement(renderer_basics_Filler__WEBPACK_IMPORTED_MODULE_1__/* ["default"] */ .Z, null),
        react__WEBPACK_IMPORTED_MODULE_0__.createElement("div", null,
            renderClassification(game.classification),
            react__WEBPACK_IMPORTED_MODULE_0__.createElement(renderer_basics_PlatformIcons__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .Z, { target: game, before: () => react__WEBPACK_IMPORTED_MODULE_0__.createElement(react__WEBPACK_IMPORTED_MODULE_0__.Fragment, null, "\u00A0\u00A0") }))));
};
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (StandardGameDesc);
function renderClassification(classification) {
    let label = [`usage_stats.description.${classification}`];
    return react__WEBPACK_IMPORTED_MODULE_0__.createElement(react__WEBPACK_IMPORTED_MODULE_0__.Fragment, null, (0,renderer_t__WEBPACK_IMPORTED_MODULE_4__.T)(label));
}


/***/ }),

/***/ 771:
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   Z: () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(7294);
/* harmony import */ var renderer_basics_GameStatusGetter__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(36);
/* harmony import */ var renderer_basics_MainAction__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(485);
/* harmony import */ var renderer_styles__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(5836);




const UncollapsibleMainAction = (0,renderer_styles__WEBPACK_IMPORTED_MODULE_3__/* ["default"] */ .ZP)((0,renderer_basics_MainAction__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .Z)) `
  flex-shrink: 0;
`;
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (({ game }) => (react__WEBPACK_IMPORTED_MODULE_0__.createElement(renderer_basics_GameStatusGetter__WEBPACK_IMPORTED_MODULE_1__/* ["default"] */ .Z, { game: game, render: (status) => react__WEBPACK_IMPORTED_MODULE_0__.createElement(UncollapsibleMainAction, { game: game, status: status }) })));


/***/ }),

/***/ 4103:
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   Z: () => (/* binding */ makeGameSeries)
/* harmony export */ });
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(7294);
/* harmony import */ var renderer_series_Series__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(58);
/* harmony import */ var renderer_pages_PageStyles_boxes__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(1625);
/* harmony import */ var renderer_pages_common_SortsAndFilters__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(7128);
/* harmony import */ var renderer_pages_common_StandardGameDesc__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(5231);
/* harmony import */ var renderer_basics_Filler__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(4333);
/* harmony import */ var reselect__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(2222);
/* harmony import */ var renderer_hocs_butlerCaller__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(5617);
/* harmony import */ var renderer_pages_common_StandardGameCover__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(7792);









let fallbackGetKey = (g) => g.id;
function makeGameSeries(rc) {
    const Series = (0,renderer_series_Series__WEBPACK_IMPORTED_MODULE_1__/* .makeSeries */ .P)(rc);
    class GameRecordComponent extends GenericGameRecordComponent {
    }
    class GameSeries extends react__WEBPACK_IMPORTED_MODULE_0__.PureComponent {
        constructor(props, context) {
            super(props, context);
            this.selector = (0,reselect__WEBPACK_IMPORTED_MODULE_6__/* .createStructuredSelector */ .zB)({
                renderDescExtras: (props) => props.renderDescExtras,
                renderItemExtras: (props) => props.renderItemExtras,
            });
        }
        render() {
            const { props } = this;
            return (react__WEBPACK_IMPORTED_MODULE_0__.createElement(Series, Object.assign({}, props, { fallbackGetKey: fallbackGetKey, RecordComponent: GameRecordComponent, extraProps: this.selector(props) })));
        }
        static getRecordCallback(f) {
            return f;
        }
        static getKeyCallback(f) {
            return f;
        }
        static renderItemExtrasCallback(f) {
            return f;
        }
    }
    return GameSeries;
}
class GenericGameRecordComponent extends react__WEBPACK_IMPORTED_MODULE_0__.PureComponent {
    render() {
        const { item, record, renderDescExtras = renderer_hocs_butlerCaller__WEBPACK_IMPORTED_MODULE_7__/* .renderNoop */ .a1, renderItemExtras = renderer_hocs_butlerCaller__WEBPACK_IMPORTED_MODULE_7__/* .renderNoop */ .a1, } = this.props;
        const game = record;
        return (react__WEBPACK_IMPORTED_MODULE_0__.createElement(renderer_pages_PageStyles_boxes__WEBPACK_IMPORTED_MODULE_2__/* .Box */ .xu, { className: "gameseries--box", "data-game-id": game.id },
            react__WEBPACK_IMPORTED_MODULE_0__.createElement(renderer_pages_PageStyles_boxes__WEBPACK_IMPORTED_MODULE_2__/* .BoxInner */ .BV, null,
                react__WEBPACK_IMPORTED_MODULE_0__.createElement(renderer_pages_common_StandardGameCover__WEBPACK_IMPORTED_MODULE_8__/* ["default"] */ .ZP, { game: game }),
                react__WEBPACK_IMPORTED_MODULE_0__.createElement(renderer_pages_common_SortsAndFilters__WEBPACK_IMPORTED_MODULE_3__/* .FilterSpacer */ .dz, null),
                react__WEBPACK_IMPORTED_MODULE_0__.createElement(renderer_pages_common_StandardGameDesc__WEBPACK_IMPORTED_MODULE_4__/* ["default"] */ .Z, { game: game }, renderDescExtras(item)),
                react__WEBPACK_IMPORTED_MODULE_0__.createElement(renderer_basics_Filler__WEBPACK_IMPORTED_MODULE_5__/* ["default"] */ .Z, null),
                react__WEBPACK_IMPORTED_MODULE_0__.createElement(renderer_pages_common_SortsAndFilters__WEBPACK_IMPORTED_MODULE_3__/* .FilterSpacer */ .dz, null),
                renderItemExtras(item),
                react__WEBPACK_IMPORTED_MODULE_0__.createElement(renderer_pages_common_SortsAndFilters__WEBPACK_IMPORTED_MODULE_3__/* .FilterSpacer */ .dz, null))));
    }
}


/***/ }),

/***/ 58:
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   P: () => (/* binding */ makeSeries)
/* harmony export */ });
/* harmony import */ var common_util_navigation__WEBPACK_IMPORTED_MODULE_16__ = __webpack_require__(9471);
/* harmony import */ var main_net_errors__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(8383);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(7294);
/* harmony import */ var react_fast_compare__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(9590);
/* harmony import */ var react_fast_compare__WEBPACK_IMPORTED_MODULE_2___default = /*#__PURE__*/__webpack_require__.n(react_fast_compare__WEBPACK_IMPORTED_MODULE_2__);
/* harmony import */ var renderer_basics_EmptyState__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(7883);
/* harmony import */ var renderer_basics_ErrorState__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(3964);
/* harmony import */ var renderer_basics_FiltersContainer__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(4987);
/* harmony import */ var renderer_basics_Floater__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(3537);
/* harmony import */ var renderer_hocs_butlerCaller__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(5617);
/* harmony import */ var renderer_hocs_hook__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(2263);
/* harmony import */ var renderer_hocs_tab_utils__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(2250);
/* harmony import */ var renderer_hocs_withTab__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(2521);
/* harmony import */ var renderer_pages_common_ItemList__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(6797);
/* harmony import */ var renderer_pages_common_Page__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(9954);
/* harmony import */ var renderer_styles__WEBPACK_IMPORTED_MODULE_13__ = __webpack_require__(5836);
/* harmony import */ var renderer_t__WEBPACK_IMPORTED_MODULE_14__ = __webpack_require__(9080);
/* harmony import */ var underscore__WEBPACK_IMPORTED_MODULE_15__ = __webpack_require__(9050);

















const LoadMoreContainer = renderer_styles__WEBPACK_IMPORTED_MODULE_13__/* ["default"] */ .ZP.div `
  height: 200px;
  display: flex;
  align-items: center;
  justify-content: center;

  &:hover {
    cursor: pointer;
  }
`;
const LoadMoreText = renderer_styles__WEBPACK_IMPORTED_MODULE_13__/* ["default"] */ .ZP.div `
  font-size: ${(props) => props.theme.fontSizes.huge};
`;
const limit = 15;
function makeSeries(rc) {
    const Call = (0,renderer_hocs_butlerCaller__WEBPACK_IMPORTED_MODULE_7__/* ["default"] */ .ZP)(rc);
    const hasItems = (result) => {
        if (!result) {
            return false;
        }
        return !(0,underscore__WEBPACK_IMPORTED_MODULE_15__/* .isEmpty */ .xb)(result.items);
    };
    class NextPageButton extends react__WEBPACK_IMPORTED_MODULE_1__.PureComponent {
        constructor() {
            super(...arguments);
            this.loadNextPage = () => {
                const { cursor, loadNextPage } = this.props;
                loadNextPage(cursor);
            };
        }
        render() {
            const { gotLoadMore } = this.props;
            return (react__WEBPACK_IMPORTED_MODULE_1__.createElement(LoadMoreContainer, { ref: gotLoadMore, onClick: this.loadNextPage },
                react__WEBPACK_IMPORTED_MODULE_1__.createElement(LoadMoreText, null, "Load more...")));
        }
    }
    class SeriesPage extends react__WEBPACK_IMPORTED_MODULE_1__.PureComponent {
        constructor() {
            super(...arguments);
            this.renderCallContents = Call.renderCallback(({ result, loading, error }) => {
                return (react__WEBPACK_IMPORTED_MODULE_1__.createElement(react__WEBPACK_IMPORTED_MODULE_1__.Fragment, null,
                    this.renderError(result, error),
                    this.renderItems(result, loading),
                    this.renderNextPage(result, loading)));
            });
        }
        render() {
            const { params, cursor, limit, sequence } = this.props;
            return (react__WEBPACK_IMPORTED_MODULE_1__.createElement(Call, { errorsHandled: true, loadingHandled: true, params: Object.assign(Object.assign({}, params), { cursor, limit }), sequence: sequence, render: this.renderCallContents }));
        }
        renderNextPage(result, loading) {
            const { gotLoadMore, loadNextPage, isLast } = this.props;
            if (result && result.nextCursor && isLast) {
                return (react__WEBPACK_IMPORTED_MODULE_1__.createElement(NextPageButton, { cursor: result.nextCursor, gotLoadMore: gotLoadMore, loadNextPage: loadNextPage }));
            }
            if (!hasItems(result) && loading) {
                return (react__WEBPACK_IMPORTED_MODULE_1__.createElement(LoadMoreContainer, null,
                    react__WEBPACK_IMPORTED_MODULE_1__.createElement(renderer_basics_Floater__WEBPACK_IMPORTED_MODULE_6__/* ["default"] */ .Z, null)));
            }
            return null;
        }
        renderError(result, error) {
            if (!error) {
                return null;
            }
            if (hasItems(result) && (0,main_net_errors__WEBPACK_IMPORTED_MODULE_0__/* .isNetworkError */ .eE)(error)) {
                return null;
            }
            return react__WEBPACK_IMPORTED_MODULE_1__.createElement(renderer_basics_ErrorState__WEBPACK_IMPORTED_MODULE_4__/* ["default"] */ .Z, { error: error });
        }
        renderItems(result, loading) {
            if (!hasItems(result)) {
                if (loading) {
                    return null;
                }
                else {
                    return this.renderEmpty();
                }
            }
            const { items } = result;
            const { fallbackGetKey, getKey, getRecord, RecordComponent, extraProps, } = this.props;
            let doneSet = new Set();
            return (react__WEBPACK_IMPORTED_MODULE_1__.createElement(react__WEBPACK_IMPORTED_MODULE_1__.Fragment, null, items.map((item) => {
                const record = getRecord(item);
                if (!record) {
                    return null;
                }
                const key = getKey ? getKey(item) : fallbackGetKey(record);
                if (doneSet.has(key)) {
                    return null;
                }
                doneSet.add(key);
                return (react__WEBPACK_IMPORTED_MODULE_1__.createElement(RecordComponent, Object.assign({ key: key, item: item, record: record }, extraProps)));
            })));
        }
        renderEmpty() {
            return (react__WEBPACK_IMPORTED_MODULE_1__.createElement(renderer_basics_EmptyState__WEBPACK_IMPORTED_MODULE_3__/* ["default"] */ .Z, { bigText: (0,renderer_t__WEBPACK_IMPORTED_MODULE_14__._)("empty_state.nothing_to_see_here"), icon: "neutral" }));
        }
    }
    class Series extends react__WEBPACK_IMPORTED_MODULE_1__.PureComponent {
        constructor(props, context) {
            super(props, context);
            this.gotItemList = (itemList) => {
                this.itemList = itemList;
            };
            this.lastScrollTop = 0;
            this.onScroll = (0,underscore__WEBPACK_IMPORTED_MODULE_15__/* .throttle */ .P2)(() => {
                const { itemList } = this;
                if (!itemList) {
                    return;
                }
                const { scrollTop, scrollHeight, clientHeight } = itemList;
                if (scrollTop < this.lastScrollTop) {
                    if (this.restoreScrollInterval) {
                        console.log(`Cancelling scroll restore (scrolled up!)`);
                        clearInterval(this.restoreScrollInterval);
                        this.restoreScrollInterval = null;
                    }
                }
                this.lastScrollTop = scrollTop;
                const runwayLeft = scrollHeight - clientHeight - scrollTop;
                const shouldLoadMore = runwayLeft < 1200;
                const { loadMore } = this;
                if (shouldLoadMore && loadMore) {
                    loadMore.click();
                }
                (0,renderer_hocs_tab_utils__WEBPACK_IMPORTED_MODULE_9__/* .dispatchTabPageUpdate */ .pq)(this.props, { scrollTop });
            }, 100);
            this.gotLoadMore = (loadMore) => {
                this.loadMore = loadMore;
            };
            this.loadNextPage = (cursor) => {
                this.setState((state) => ({
                    cursors: [...state.cursors, cursor],
                }));
            };
            this.state = {
                cursors: [null],
                lastParams: null,
            };
            if (props.restoredScrollTop) {
                console.log(`Aiming for scrollTop ${props.restoredScrollTop}`);
                this.restoreScrollInterval = window.setInterval(() => {
                    if (this.itemList) {
                        this.itemList.scrollTop = props.restoredScrollTop;
                        const { scrollTop } = this.itemList;
                        if (scrollTop === props.restoredScrollTop) {
                            console.log(`Done adjusting, final scrollTop = ${scrollTop}`);
                            clearInterval(this.restoreScrollInterval);
                            this.restoreScrollInterval = null;
                        }
                    }
                }, 160);
            }
        }
        componentWillUnmount() {
            if (this.restoreScrollInterval) {
                clearInterval(this.restoreScrollInterval);
                this.restoreScrollInterval = null;
            }
        }
        static getDerivedStateFromProps(props, state) {
            if (!react_fast_compare__WEBPACK_IMPORTED_MODULE_2___default()(props.params, state.lastParams)) {
                return {
                    cursors: [null],
                    lastParams: props.params,
                };
            }
            return null;
        }
        getSnapshotBeforeUpdate(prevProps, prevState) {
            if (!react_fast_compare__WEBPACK_IMPORTED_MODULE_2___default()(this.props.params, prevProps.params)) {
                return {
                    resetScroll: true,
                };
            }
            return null;
        }
        componentDidUpdate(props, state, snapshot) {
            if (snapshot && snapshot.resetScroll && this.itemList) {
                console.log(`resetting scrollTop!`);
                this.itemList.scrollTop = 0;
                (0,renderer_hocs_tab_utils__WEBPACK_IMPORTED_MODULE_9__/* .dispatchTabPageUpdate */ .pq)(this.props, { scrollTop: 0 });
            }
        }
        componentDidMount() {
            const { label } = this.props;
            if (label) {
                (0,renderer_hocs_tab_utils__WEBPACK_IMPORTED_MODULE_9__/* .dispatchTabPageUpdate */ .pq)(this.props, { label });
            }
        }
        render() {
            const { params, sequence } = this.props;
            const { renderMainFilters = renderer_hocs_butlerCaller__WEBPACK_IMPORTED_MODULE_7__/* .renderNoop */ .a1, renderExtraFilters = renderer_hocs_butlerCaller__WEBPACK_IMPORTED_MODULE_7__/* .renderNoop */ .a1, fallbackGetKey, getKey, getRecord, RecordComponent, extraProps, } = this.props;
            const { cursors } = this.state;
            return (react__WEBPACK_IMPORTED_MODULE_1__.createElement(renderer_pages_common_Page__WEBPACK_IMPORTED_MODULE_12__/* ["default"] */ .Z, null,
                react__WEBPACK_IMPORTED_MODULE_1__.createElement(renderer_basics_FiltersContainer__WEBPACK_IMPORTED_MODULE_5__/* ["default"] */ .ZP, { loading: false }, renderMainFilters ? renderMainFilters() : null),
                renderExtraFilters ? renderExtraFilters() : null,
                react__WEBPACK_IMPORTED_MODULE_1__.createElement(renderer_pages_common_ItemList__WEBPACK_IMPORTED_MODULE_11__/* ["default"] */ .Z, { className: "series--itemlist", onScroll: this.onScroll, ref: this.gotItemList }, cursors.map((cursor, i) => (react__WEBPACK_IMPORTED_MODULE_1__.createElement(SeriesPage, { key: i, params: params, cursor: cursor, limit: limit, sequence: sequence, isLast: i === cursors.length - 1, gotLoadMore: this.gotLoadMore, loadNextPage: this.loadNextPage, fallbackGetKey: fallbackGetKey, getKey: getKey, getRecord: getRecord, RecordComponent: RecordComponent, extraProps: extraProps }))))));
        }
    }
    return (0,renderer_hocs_withTab__WEBPACK_IMPORTED_MODULE_10__/* .withTab */ .D1)((0,renderer_hocs_hook__WEBPACK_IMPORTED_MODULE_8__/* .hookWithProps */ .h)(Series)((map) => ({
        sequence: map((rs, props) => (0,common_util_navigation__WEBPACK_IMPORTED_MODULE_16__/* .ambientTab */ .mB)(rs, props).sequence),
        restoredScrollTop: map((rs, props) => (0,common_util_navigation__WEBPACK_IMPORTED_MODULE_16__/* .ambientPage */ .Jb)(rs, props).restoredScrollTop),
    }))(Series));
}


/***/ })

}]);
//# sourceMappingURL=301.chunk.js.map