"use strict";
(self["webpackChunkLIB"] = self["webpackChunkLIB"] || []).push([[645],{

/***/ 992:
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   Nd: () => (/* binding */ getRpcErrorData),
/* harmony export */   SS: () => (/* binding */ isInternalError),
/* harmony export */   dt: () => (/* binding */ getErrorStack),
/* harmony export */   mg: () => (/* binding */ asRequestError)
/* harmony export */ });
/* unused harmony export mergeLogAndError */
/* harmony import */ var common_logger__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(8976);
/* harmony import */ var common_format_datetime__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(1061);


function asRequestError(e) {
    const re = e;
    if (re.rpcError) {
        return e;
    }
    return null;
}
function getRpcErrorData(e) {
    const re = asRequestError(e);
    if (re && re.rpcError && re.rpcError.data) {
        return re.rpcError.data;
    }
    return null;
}
function isInternalError(e) {
    const re = asRequestError(e);
    if (!re) {
        return true;
    }
    if (re.rpcError.code < 0) {
        return true;
    }
    return false;
}
function getErrorStack(e) {
    if (!e) {
        return "Unknown error";
    }
    let errorStack = e.stack;
    const re = asRequestError(e);
    if (re) {
        const ed = getRpcErrorData(e);
        if (ed && ed.stack) {
            // use golang stack if available
            errorStack = ed.stack;
        }
        else if (re.message) {
            // or just message
            errorStack = re.message;
        }
    }
    return errorStack;
}
function mergeLogAndError(log, e) {
    let formattedLog = "";
    if (log) {
        let lines = log.split("\n");
        for (let line of lines) {
            line = line.trim();
            let fallback = false;
            try {
                const obj = JSON.parse(line);
                if (obj.msg) {
                    let date = formatDate(new Date(obj.time), "en-US", DATE_FORMAT);
                    let level = levels[obj.level];
                    let { msg } = obj;
                    formattedLog += `${date} [${level}] ${msg}\n`;
                }
                else {
                    fallback = true;
                }
            }
            catch (e) {
                fallback = true;
            }
            if (fallback) {
                formattedLog += `${line}\n`;
            }
        }
    }
    return `${formattedLog}\n\nError stack:\n${getErrorStack(e)}\n`;
}


/***/ }),

/***/ 8383:
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   eE: () => (/* binding */ isNetworkError)
/* harmony export */ });
/* unused harmony exports RequestError, RequestTimeout, RequestAborted, RequestFormattingFailure, RequestParsingFailure */
/* harmony import */ var common_butlerd_errors__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(992);
/* harmony import */ var common_butlerd_messages__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(4713);


/**
 * Returns true if this is a network error
 */
function isNetworkError(e) {
    // this operates under the assumption that:
    //   * all our internal network errors should start with "err::"
    //   * all of chrome's already do
    //   * we transform fetch's into err:: variants.
    // we coerce e.message into a string on the off chance that it's not defined
    // or not a string.
    const isJavaScriptNetworkError = e && ("" + e.message).indexOf("net::") === 0;
    if (isJavaScriptNetworkError) {
        return true;
    }
    const re = (0,common_butlerd_errors__WEBPACK_IMPORTED_MODULE_0__/* .asRequestError */ .mg)(e);
    if (re) {
        if (re.rpcError.code === common_butlerd_messages__WEBPACK_IMPORTED_MODULE_1__/* .Code */ .EK.NetworkDisconnected) {
            return true;
        }
    }
    return false;
}
class RequestError extends (/* unused pure expression or super */ null && (Error)) {
    constructor(message) {
        super(message.indexOf("net::") == 0 ? message : "net::REQUEST_ERROR::");
    }
}
class RequestTimeout extends (/* unused pure expression or super */ null && (RequestError)) {
    constructor() {
        super("TIMED_OUT");
    }
}
class RequestAborted extends (/* unused pure expression or super */ null && (RequestError)) {
    constructor() {
        super("ABORTED");
    }
}
class RequestFormattingFailure extends (/* unused pure expression or super */ null && (RequestError)) {
    constructor(message) {
        super("FORMATTING_FAILURE: " + message);
    }
}
class RequestParsingFailure extends (/* unused pure expression or super */ null && (RequestError)) {
    constructor(message) {
        super("PARSING_FAILURE: " + message);
    }
}


/***/ }),

/***/ 7883:
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   Z: () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(7294);
/* harmony import */ var renderer_basics_Button__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(6025);
/* harmony import */ var renderer_basics_Icon__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(4198);
/* harmony import */ var renderer_styles__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(5836);
/* harmony import */ var renderer_t__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(9080);





const EmptyStateDiv = renderer_styles__WEBPACK_IMPORTED_MODULE_3__/* ["default"] */ .ZP.div `
  color: ${(props) => props.theme.secondaryText};
  width: 100%;
  text-align: center;
  margin: 60px 0;

  .leader {
    display: inline-block;
    font-size: 170px;
    margin-bottom: 20px;
  }

  h1 {
    font-size: ${(props) => props.theme.fontSizes.enormous};
    font-weight: bold;
    margin-bottom: 10px;
  }

  h2 {
    font-size: ${(props) => props.theme.fontSizes.huge};
  }
`;
const ButtonContainer = renderer_styles__WEBPACK_IMPORTED_MODULE_3__/* ["default"] */ .ZP.div `
  margin: 20px;
  display: inline-block;
`;
const EmptyStateContainer = renderer_styles__WEBPACK_IMPORTED_MODULE_3__/* ["default"] */ .ZP.div `
  display: flex;
  width: 100%;
  height: 100%;
  align-items: center;
  overflow: hidden;
`;
class EmptyState extends react__WEBPACK_IMPORTED_MODULE_0__.PureComponent {
    render() {
        const { bigText, smallText, icon, buttonIcon, buttonText, buttonAction, componentAction, className, } = this.props;
        return (react__WEBPACK_IMPORTED_MODULE_0__.createElement(EmptyStateContainer, null,
            react__WEBPACK_IMPORTED_MODULE_0__.createElement(EmptyStateDiv, { className: className },
                react__WEBPACK_IMPORTED_MODULE_0__.createElement(renderer_basics_Icon__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .Z, { icon: icon, className: "leader" }),
                react__WEBPACK_IMPORTED_MODULE_0__.createElement("h1", null, (0,renderer_t__WEBPACK_IMPORTED_MODULE_4__.T)(bigText)),
                smallText ? react__WEBPACK_IMPORTED_MODULE_0__.createElement("h2", null, (0,renderer_t__WEBPACK_IMPORTED_MODULE_4__.T)(smallText)) : null,
                componentAction,
                buttonAction ? (react__WEBPACK_IMPORTED_MODULE_0__.createElement(react__WEBPACK_IMPORTED_MODULE_0__.Fragment, null,
                    react__WEBPACK_IMPORTED_MODULE_0__.createElement(ButtonContainer, null,
                        react__WEBPACK_IMPORTED_MODULE_0__.createElement(renderer_basics_Button__WEBPACK_IMPORTED_MODULE_1__/* ["default"] */ .Z, { icon: buttonIcon, primary: true, onClick: buttonAction }, (0,renderer_t__WEBPACK_IMPORTED_MODULE_4__.T)(buttonText))))) : null)));
    }
}
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (EmptyState);


/***/ }),

/***/ 6645:
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

// ESM COMPAT FLAG
__webpack_require__.r(__webpack_exports__);

// EXPORTS
__webpack_require__.d(__webpack_exports__, {
  "default": () => (/* binding */ pages_CollectionsPage)
});

// EXTERNAL MODULE: ./node_modules/react/index.js
var react = __webpack_require__(7294);
// EXTERNAL MODULE: ./src/renderer/styles.ts
var styles = __webpack_require__(5836);
// EXTERNAL MODULE: ./src/renderer/hocs/withTab.tsx
var withTab = __webpack_require__(2521);
// EXTERNAL MODULE: ./src/renderer/hocs/hook.tsx
var hook = __webpack_require__(2263);
// EXTERNAL MODULE: ./src/common/util/navigation.ts
var navigation = __webpack_require__(9471);
// EXTERNAL MODULE: ./src/renderer/hocs/withProfile.tsx
var withProfile = __webpack_require__(953);
// EXTERNAL MODULE: ./src/common/butlerd/messages.ts
var messages = __webpack_require__(4713);
// EXTERNAL MODULE: ./src/renderer/basics/TimeAgo.tsx + 2 modules
var TimeAgo = __webpack_require__(8923);
// EXTERNAL MODULE: ./src/renderer/pages/common/GameStripe.tsx
var GameStripe = __webpack_require__(7840);
// EXTERNAL MODULE: ./src/renderer/t.tsx + 2 modules
var t = __webpack_require__(9080);
;// CONCATENATED MODULE: ./src/renderer/pages/CollectionsPage/CollectionPreview.tsx








const CollectionGameStripe = (0,GameStripe/* makeGameStripe */.k)(messages/* FetchCollectionGames */.ff);
const CollectionInfo = styles/* default */.ZP.div `
  display: flex;
  flex-direction: row;
  align-items: center;

  font-size: ${(props) => props.theme.fontSizes.baseText};
  color: ${(props) => props.theme.ternaryText};
  font-weight: 700;
  margin: 0 0.5em;
`;
const CollectionInfoSpacer = styles/* default */.ZP.div `
  width: 0.4em;
`;
class CollectionPreview extends react.PureComponent {
    constructor() {
        super(...arguments);
        this.getGame = CollectionGameStripe.getGameCallback((cg) => cg.game);
        this.renderTitleExtras = () => {
            const { coll } = this.props;
            return (react.createElement(react.Fragment, null,
                react.createElement(CollectionInfoSpacer, null),
                react.createElement(CollectionInfo, null, (0,t.T)(["collection.item_count", { itemCount: coll.gamesCount }])),
                react.createElement(CollectionInfo, null,
                    (0,t.T)(["collection.info.updated"]),
                    react.createElement(CollectionInfoSpacer, null),
                    react.createElement(TimeAgo/* default */.Z, { date: coll.updatedAt }))));
        };
    }
    render() {
        const { profile, coll } = this.props;
        return (react.createElement(CollectionGameStripe, { title: coll.title, href: (0,navigation/* urlForCollection */.uW)(coll.id), params: { profileId: profile.id, collectionId: coll.id }, renderTitleExtras: this.renderTitleExtras, getGame: this.getGame }));
    }
}
/* harmony default export */ const CollectionsPage_CollectionPreview = ((0,withProfile/* withProfile */.Yh)(CollectionPreview));

// EXTERNAL MODULE: ./src/renderer/series/Series.tsx
var series_Series = __webpack_require__(58);
// EXTERNAL MODULE: ./node_modules/reselect/es/index.js
var es = __webpack_require__(2222);
;// CONCATENATED MODULE: ./src/renderer/series/CollectionSeries.tsx




let fallbackGetKey = (c) => c.id;
function makeCollectionSeries(rc) {
    const Series = (0,series_Series/* makeSeries */.P)(rc);
    class CollectionRecordComponent extends GenericCollectionRecordComponent {
    }
    class CollectionSeries extends react.PureComponent {
        constructor(props, context) {
            super(props, context);
            this.selector = (0,es/* createStructuredSelector */.zB)({});
        }
        render() {
            const { props } = this;
            return (react.createElement(Series, Object.assign({}, props, { fallbackGetKey: fallbackGetKey, RecordComponent: CollectionRecordComponent, extraProps: this.selector(props) })));
        }
        static getRecordCallback(f) {
            return f;
        }
        static renderItemExtrasCallback(f) {
            return f;
        }
    }
    return CollectionSeries;
}
class GenericCollectionRecordComponent extends react.PureComponent {
    render() {
        const { item, record } = this.props;
        const coll = record;
        return react.createElement(CollectionsPage_CollectionPreview, { coll: coll });
    }
}

// EXTERNAL MODULE: ./src/renderer/pages/common/SearchControl.tsx + 1 modules
var SearchControl = __webpack_require__(2315);
// EXTERNAL MODULE: ./src/renderer/pages/common/SortsAndFilters.tsx
var SortsAndFilters = __webpack_require__(7128);
// EXTERNAL MODULE: ./src/renderer/basics/IconButton.tsx
var IconButton = __webpack_require__(5391);
// EXTERNAL MODULE: ./src/common/actions/index.ts
var actions = __webpack_require__(2448);
// EXTERNAL MODULE: ./src/common/constants/urls.ts
var urls = __webpack_require__(541);
// EXTERNAL MODULE: ./src/renderer/pages/common/Sort.tsx
var Sort = __webpack_require__(1945);
;// CONCATENATED MODULE: ./src/renderer/pages/CollectionsPage/index.tsx















const ProfileCollectionsSeries = makeCollectionSeries(messages/* FetchProfileCollections */.FS);
const CollectionsDiv = styles/* default */.ZP.div `
  ${styles/* meat */.pw};
`;
class CollectionsPage extends react.PureComponent {
    constructor() {
        super(...arguments);
        this.getRecord = ProfileCollectionsSeries.getRecordCallback((c) => c);
        this.renderMainFilters = () => {
            return (react.createElement(react.Fragment, null,
                react.createElement(SearchControl/* default */.Z, null),
                react.createElement(SortsAndFilters/* FilterSpacer */.dz, null),
                react.createElement(IconButton/* default */.Z, { icon: "more_vert", onClick: this.onMore })));
        };
        this.renderExtraFilters = () => {
            return (react.createElement(SortsAndFilters/* SortsAndFilters */.gY, null,
                react.createElement(SortsAndFilters/* FilterGroup */.e_, null,
                    react.createElement(Sort/* SortOption */.Y, { sortBy: "title", label: (0,t._)("sort_by.collections.title") }),
                    react.createElement(Sort/* SortOption */.Y, { sortBy: "updatedAt", label: (0,t._)("sort_by.collections.updated_at") }))));
        };
        this.onMore = (ev) => {
            const { dispatch, tab, url } = this.props;
            const { clientX, clientY } = ev;
            dispatch(actions/* actions */.N.popupContextMenu({
                wind: (0,navigation/* ambientWind */.w)(),
                clientX,
                clientY,
                template: [
                    {
                        localizedLabel: ["outlinks.manage_collections"],
                        action: actions/* actions */.N.navigate({
                            wind: (0,navigation/* ambientWind */.w)(),
                            url: urls/* default */.Z.myCollections,
                        }),
                    },
                ],
            }));
        };
    }
    render() {
        const { profile, search, sortBy, sortDir } = this.props;
        return (react.createElement(CollectionsDiv, null,
            react.createElement(ProfileCollectionsSeries, { label: (0,t._)("sidebar.collections"), getRecord: this.getRecord, params: {
                    profileId: profile.id,
                    sortBy,
                    reverse: sortDir === "reverse",
                    search,
                }, renderMainFilters: this.renderMainFilters, renderExtraFilters: this.renderExtraFilters })));
    }
}
const hooked = (0,hook/* hookWithProps */.h)(CollectionsPage)((map) => ({
    url: map((rs, props) => (0,navigation/* ambientTab */.mB)(rs, props).location.url),
    sortBy: map((rs, props) => (0,navigation/* ambientTab */.mB)(rs, props).location.query.sortBy),
    sortDir: map((rs, props) => (0,navigation/* ambientTab */.mB)(rs, props).location.query.sortDir),
    search: map((rs, props) => (0,navigation/* ambientTab */.mB)(rs, props).location.query.search),
}))(CollectionsPage);
/* harmony default export */ const pages_CollectionsPage = ((0,withTab/* withTab */.D1)((0,withProfile/* withProfile */.Yh)(hooked)));


/***/ }),

/***/ 7840:
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   k: () => (/* binding */ makeGameStripe)
/* harmony export */ });
/* unused harmony export makeStripeCallbacks */
/* harmony import */ var tslib__WEBPACK_IMPORTED_MODULE_13__ = __webpack_require__(655);
/* harmony import */ var common_util_navigation__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(9471);
/* harmony import */ var main_net_errors__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(8383);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(7294);
/* harmony import */ var renderer_basics_ErrorState__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(3964);
/* harmony import */ var renderer_basics_Floater__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(3537);
/* harmony import */ var renderer_hocs_butlerCaller__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(5617);
/* harmony import */ var renderer_hocs_hook__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(2263);
/* harmony import */ var renderer_hocs_withTab__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(2521);
/* harmony import */ var renderer_pages_PageStyles_games__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(465);
/* harmony import */ var renderer_styles__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(5836);
/* harmony import */ var renderer_t__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(9080);
/* harmony import */ var underscore__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(9050);
/* harmony import */ var renderer_pages_common_StandardGameCover__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(7792);














const StripeDiv = renderer_styles__WEBPACK_IMPORTED_MODULE_8__/* ["default"] */ .ZP.div `
  display: flex;
  flex-direction: row;
  align-items: center;
  width: 100%;
  overflow: hidden;
  position: relative;

  height: ${renderer_pages_common_StandardGameCover__WEBPACK_IMPORTED_MODULE_11__/* .standardCoverHeight */ .xb + 2}px;

  padding: 1.2em 0;
  margin-bottom: 32px;
`;
const FloaterContainer = renderer_styles__WEBPACK_IMPORTED_MODULE_8__/* ["default"] */ .ZP.div `
  background: ${(props) => props.theme.breadBackground};
  opacity: 0.7;
  padding: 4px;

  position: absolute;
  left: 5px;
  top: 5px;
  z-index: 20;
`;
const ViewAll = renderer_styles__WEBPACK_IMPORTED_MODULE_8__/* ["default"] */ .ZP.a `
  position: absolute;
  background: ${(props) => props.theme.breadBackground};
  box-shadow: 0 0 30px ${(props) => props.theme.breadBackground};
  padding: 0 4em;
  top: 0;
  bottom: 0;
  right: 0;
  display: flex;
  flex-direction: row;
  align-items: center;
  overflow: hidden;

  z-index: 4;
`;
const StripeItemDiv = renderer_styles__WEBPACK_IMPORTED_MODULE_8__/* ["default"] */ .ZP.div `
  ${renderer_styles__WEBPACK_IMPORTED_MODULE_8__/* .boxy */ .wN};
  flex-shrink: 0;
  margin-right: 0.8em;
`;
const stripeLimit = 12;
function makeGameStripe(rc) {
    const Call = (0,renderer_hocs_butlerCaller__WEBPACK_IMPORTED_MODULE_4__/* ["default"] */ .ZP)(rc);
    const hasItems = (result) => {
        if (!result) {
            return false;
        }
        return !(0,underscore__WEBPACK_IMPORTED_MODULE_10__/* .isEmpty */ .xb)(result.items);
    };
    class Stripe extends react__WEBPACK_IMPORTED_MODULE_1__.PureComponent {
        constructor() {
            super(...arguments);
            this.renderCallContents = Call.renderCallback(({ result, error, loading }) => (react__WEBPACK_IMPORTED_MODULE_1__.createElement(react__WEBPACK_IMPORTED_MODULE_1__.Fragment, null,
                this.renderTitle(loading, result, error),
                react__WEBPACK_IMPORTED_MODULE_1__.createElement(StripeDiv, null,
                    loading ? (react__WEBPACK_IMPORTED_MODULE_1__.createElement(FloaterContainer, null,
                        react__WEBPACK_IMPORTED_MODULE_1__.createElement(renderer_basics_Floater__WEBPACK_IMPORTED_MODULE_3__/* ["default"] */ .Z, null))) : null,
                    this.renderViewAll(),
                    this.renderItems(result),
                    this.renderEmpty()))));
        }
        render() {
            const { params, sequence } = this.props;
            return (react__WEBPACK_IMPORTED_MODULE_1__.createElement(Call, { params: Object.assign(Object.assign({}, params), { limit: stripeLimit }), sequence: sequence, loadingHandled: true, errorsHandled: true, render: this.renderCallContents }));
        }
        renderTitle(loading, result, error) {
            const { linkId, href, title, renderTitleExtras = renderNoop, } = this.props;
            return (react__WEBPACK_IMPORTED_MODULE_1__.createElement(react__WEBPACK_IMPORTED_MODULE_1__.Fragment, null,
                react__WEBPACK_IMPORTED_MODULE_1__.createElement(renderer_pages_PageStyles_games__WEBPACK_IMPORTED_MODULE_7__/* .TitleBox */ .kS, null,
                    react__WEBPACK_IMPORTED_MODULE_1__.createElement(renderer_pages_PageStyles_games__WEBPACK_IMPORTED_MODULE_7__/* .Title */ .Dx, null,
                        react__WEBPACK_IMPORTED_MODULE_1__.createElement("a", { id: linkId, href: href }, (0,renderer_t__WEBPACK_IMPORTED_MODULE_9__.T)(title)),
                        renderTitleExtras())),
                this.renderError(result, error)));
        }
        renderError(result, error) {
            if (!error) {
                return null;
            }
            if (hasItems(result) && (0,main_net_errors__WEBPACK_IMPORTED_MODULE_0__/* .isNetworkError */ .eE)(error)) {
                return null;
            }
            return react__WEBPACK_IMPORTED_MODULE_1__.createElement(renderer_basics_ErrorState__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .Z, { error: error });
        }
        renderItems(result) {
            if (!result) {
                return null;
            }
            if ((0,underscore__WEBPACK_IMPORTED_MODULE_10__/* .isEmpty */ .xb)(result.items)) {
                return null;
            }
            const doneSet = new Set();
            const { getGame } = this.props;
            return (react__WEBPACK_IMPORTED_MODULE_1__.createElement(react__WEBPACK_IMPORTED_MODULE_1__.Fragment, null, result.items.map((item) => {
                const game = getGame(item);
                if (!game || doneSet.has(game.id)) {
                    return null;
                }
                doneSet.add(game.id);
                return (react__WEBPACK_IMPORTED_MODULE_1__.createElement(StripeItem, { key: game.id, className: "stripe--item", "data-game-id": game.id, game: game }));
            })));
        }
        renderEmpty() {
            const { dispatch } = this.props;
            return (react__WEBPACK_IMPORTED_MODULE_1__.createElement(react__WEBPACK_IMPORTED_MODULE_1__.Fragment, null, [0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12].map((id) => (react__WEBPACK_IMPORTED_MODULE_1__.createElement(StripeItem, { key: `empty-${id}` })))));
        }
        renderViewAll() {
            return (react__WEBPACK_IMPORTED_MODULE_1__.createElement(ViewAll, { href: this.props.href }, (0,renderer_t__WEBPACK_IMPORTED_MODULE_9__.T)(["game_stripe.view_all"])));
        }
    }
    let result = (0,renderer_hocs_withTab__WEBPACK_IMPORTED_MODULE_6__/* .withTab */ .D1)((0,renderer_hocs_hook__WEBPACK_IMPORTED_MODULE_5__/* .hookWithProps */ .h)(Stripe)((map) => ({
        sequence: map((rs, props) => (0,common_util_navigation__WEBPACK_IMPORTED_MODULE_12__/* .ambientTab */ .mB)(rs, props).sequence),
    }))(Stripe));
    function identity(t) {
        return t;
    }
    let augmentedResult = result;
    augmentedResult.getGameCallback = identity;
    return augmentedResult;
}
function makeStripeCallbacks(rc) {
    return {
        getGame(f) {
            return f;
        },
    };
}
function renderNoop() {
    return null;
}
class StripeItem extends react__WEBPACK_IMPORTED_MODULE_1__.PureComponent {
    render() {
        const _a = this.props, { game } = _a, restProps = (0,tslib__WEBPACK_IMPORTED_MODULE_13__/* .__rest */ ._T)(_a, ["game"]);
        return (react__WEBPACK_IMPORTED_MODULE_1__.createElement(StripeItemDiv, Object.assign({}, restProps),
            react__WEBPACK_IMPORTED_MODULE_1__.createElement(renderer_pages_common_StandardGameCover__WEBPACK_IMPORTED_MODULE_11__/* ["default"] */ .ZP, { game: game, showInfo: true })));
    }
}


/***/ }),

/***/ 6797:
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   Z: () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony import */ var renderer_styles__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(5836);

/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (renderer_styles__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .ZP.div `
  flex-grow: 1;
  overflow-y: auto;
  padding: 0 12px;

  user-select: none;

  /* this scrolls, so we want it to have its own layer */
  will-change: transform;
`);


/***/ }),

/***/ 2315:
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {


// EXPORTS
__webpack_require__.d(__webpack_exports__, {
  Z: () => (/* binding */ common_SearchControl)
});

// EXTERNAL MODULE: ./src/common/util/navigation.ts
var navigation = __webpack_require__(9471);
// EXTERNAL MODULE: ./node_modules/react/index.js
var react = __webpack_require__(7294);
// EXTERNAL MODULE: ./src/renderer/hocs/hook.tsx
var hook = __webpack_require__(2263);
// EXTERNAL MODULE: ./src/renderer/hocs/tab-utils.tsx
var tab_utils = __webpack_require__(2250);
// EXTERNAL MODULE: ./src/renderer/hocs/withTab.tsx
var withTab = __webpack_require__(2521);
// EXTERNAL MODULE: ./src/renderer/styles.ts
var styles = __webpack_require__(5836);
;// CONCATENATED MODULE: ./src/renderer/pages/common/FilterInput.tsx


const StyledInput = styles/* default */.ZP.input `
  ${styles/* searchInput */.eK};
  width: 20em;
  padding-left: 10px;
  margin-left: 1.4em;
  border: 1px solid rgba(255, 255, 255, 0.1);
  background: rgba(0, 0, 0, 0.3);
`;
/* harmony default export */ const FilterInput = ((props) => react.createElement(StyledInput, Object.assign({ type: "search" }, props)));

// EXTERNAL MODULE: ./src/renderer/t.tsx + 2 modules
var t = __webpack_require__(9080);
// EXTERNAL MODULE: ./node_modules/underscore/modules/index-all.js + 160 modules
var index_all = __webpack_require__(9050);
// EXTERNAL MODULE: ./node_modules/react-intl/lib/src/components/injectIntl.js
var injectIntl = __webpack_require__(4806);
;// CONCATENATED MODULE: ./src/renderer/pages/common/SearchControl.tsx









class SearchControl extends react.PureComponent {
    constructor() {
        super(...arguments);
        this.onSearchChange = (e) => {
            this.setSearch(e.currentTarget.value);
        };
        this.setSearch = (0,index_all/* debounce */.Ds)((search) => {
            const { url } = this.props;
            (0,tab_utils/* dispatchTabEvolve */.vV)(this.props, {
                replace: true,
                url: (0,tab_utils/* urlWithParams */.Iq)(url, { search }),
            });
        }, 250);
    }
    render() {
        const { defaultValue } = this.props;
        return (react.createElement(FilterInput, { defaultValue: defaultValue, placeholder: (0,t/* TString */.m)(this.props.intl, ["grid.criterion.filter"]), onChange: this.onSearchChange }));
    }
}
/* harmony default export */ const common_SearchControl = ((0,withTab/* withTab */.D1)((0,injectIntl/* default */.ZP)((0,hook/* hookWithProps */.h)(SearchControl)((map) => ({
    url: map((rs, props) => (0,navigation/* ambientTab */.mB)(rs, props).location.url),
    defaultValue: map((rs, props) => (0,navigation/* ambientTab */.mB)(rs, props).location.query.search),
}))(SearchControl))));


/***/ }),

/***/ 1945:
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   Y: () => (/* binding */ SortOption)
/* harmony export */ });
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(4184);
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(classnames__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var common_util_navigation__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(9471);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(7294);
/* harmony import */ var renderer_hocs_hook__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(2263);
/* harmony import */ var renderer_hocs_tab_utils__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(2250);
/* harmony import */ var renderer_hocs_withTab__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(2521);
/* harmony import */ var renderer_pages_common_SortsAndFilters__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(7128);
/* harmony import */ var renderer_t__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(9080);








const SortOptionBase = (props) => {
    const { url, active, reverse, sortBy, label } = props;
    let href;
    let baseClass = `sortby--${sortBy}`;
    if (!active) {
        baseClass = `${baseClass}--default`;
        href = (0,renderer_hocs_tab_utils__WEBPACK_IMPORTED_MODULE_3__/* .urlWithParams */ .Iq)(url, { sortBy, sortDir: "default" });
    }
    else {
        if (!reverse) {
            baseClass = `${baseClass}--reverse`;
            href = (0,renderer_hocs_tab_utils__WEBPACK_IMPORTED_MODULE_3__/* .urlWithParams */ .Iq)(url, { sortBy, sortDir: "reverse" });
        }
        else {
            baseClass = `${baseClass}--disable`;
            href = (0,renderer_hocs_tab_utils__WEBPACK_IMPORTED_MODULE_3__/* .urlWithParams */ .Iq)(url, { sortBy: undefined, sortDir: undefined });
        }
    }
    return (react__WEBPACK_IMPORTED_MODULE_1__.createElement(renderer_pages_common_SortsAndFilters__WEBPACK_IMPORTED_MODULE_5__/* .FilterOptionLink */ .zR, { target: "_replace", href: href, className: classnames__WEBPACK_IMPORTED_MODULE_0___default()(baseClass, { active }) },
        react__WEBPACK_IMPORTED_MODULE_1__.createElement(renderer_pages_common_SortsAndFilters__WEBPACK_IMPORTED_MODULE_5__/* .FilterOptionIcon */ .Zk, { className: classnames__WEBPACK_IMPORTED_MODULE_0___default()({ inactive: !active }), icon: active && reverse ? "sort-amount-desc" : "sort-amount-asc" }),
        (0,renderer_t__WEBPACK_IMPORTED_MODULE_6__.T)(label)));
};
const hooked = (0,renderer_hocs_hook__WEBPACK_IMPORTED_MODULE_2__/* .hookWithProps */ .h)(SortOptionBase)((map) => ({
    url: map((rs, props) => (0,common_util_navigation__WEBPACK_IMPORTED_MODULE_7__/* .ambientTab */ .mB)(rs, props).location.url),
    active: map((rs, props) => (0,common_util_navigation__WEBPACK_IMPORTED_MODULE_7__/* .ambientTab */ .mB)(rs, props).location.query.sortBy === props.sortBy),
    reverse: map((rs, props) => (0,common_util_navigation__WEBPACK_IMPORTED_MODULE_7__/* .ambientTab */ .mB)(rs, props).location.query.sortDir === "reverse"),
}))(SortOptionBase);
const SortOption = (0,renderer_hocs_withTab__WEBPACK_IMPORTED_MODULE_4__/* .withTab */ .D1)(hooked);


/***/ }),

/***/ 7128:
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   Ni: () => (/* binding */ FilterOptionButton),
/* harmony export */   Zk: () => (/* binding */ FilterOptionIcon),
/* harmony export */   dz: () => (/* binding */ FilterSpacer),
/* harmony export */   e_: () => (/* binding */ FilterGroup),
/* harmony export */   gY: () => (/* binding */ SortsAndFilters),
/* harmony export */   zR: () => (/* binding */ FilterOptionLink)
/* harmony export */ });
/* harmony import */ var renderer_basics_FiltersContainer__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(4987);
/* harmony import */ var renderer_basics_Icon__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(4198);
/* harmony import */ var renderer_styles__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(5836);



const SortsAndFilters = (0,renderer_styles__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .ZP)((0,renderer_basics_FiltersContainer__WEBPACK_IMPORTED_MODULE_0__/* .FiltersContainerDiv */ .vN)) `
  display: flex;
  justify-content: center;
  flex-flow: row wrap;
  height: auto;

  padding: 0.4em 0.6em;
  font-weight: normal;
`;
const FilterGroup = renderer_styles__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .ZP.div `
  margin: 0.5em 0;
  display: flex;
  flex-flow: row wrap;
`;
// const inactiveBg = `linear-gradient(to top,hsla(355, 43%, 25%, 1),hsla(355, 43%, 17%, 1))`;
// const activeBg = `linear-gradient(to top, hsla(355, 43%, 50%, 1), hsla(355, 43%, 37%, 1));`;
const inactiveBg = `linear-gradient(to top,hsla(355, 43%, 17%, 1),hsla(355, 43%, 11%, 1))`;
const activeBg = `linear-gradient(to top, hsla(355, 43%, 33%, 1), hsla(355, 43%, 22%, 1));`;
const borderColor = `#843442`;
const borderRadius = `4px`;
const optionButtonLike = (0,renderer_styles__WEBPACK_IMPORTED_MODULE_2__/* .css */ .iv) `
  display: flex;
  flex-flow: row;
  align-items: center;

  background: ${inactiveBg};
  padding: 0.5em 1em;
  margin: 0;
  border: 1px solid ${borderColor};
  border-left: none;
  color: ${(props) => props.theme.baseText};
  transition: all 0.4s;

  &:first-child {
    border-radius: ${borderRadius} 0 0 ${borderRadius};
    border-left: 1px solid ${borderColor};
  }

  &:last-child {
    border-radius: 0 ${borderRadius} ${borderRadius} 0;
  }

  &:first-child:last-child {
    border-radius: ${borderRadius};
  }

  &.active {
    background: ${activeBg};
    color: ${(props) => props.theme.baseText};
  }

  &:hover {
    cursor: pointer;
  }
`;
const FilterOptionLink = renderer_styles__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .ZP.a `
  ${optionButtonLike};

  &.disabled {
    pointer-events: none;
    opacity: 0.4;
  }
`;
const FilterOptionButton = renderer_styles__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .ZP.div `
  ${optionButtonLike};
`;
const FilterOptionIcon = (0,renderer_styles__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .ZP)((0,renderer_basics_Icon__WEBPACK_IMPORTED_MODULE_1__/* ["default"] */ .Z)) `
  margin-right: 0.5em;
  font-size: 80%;

  opacity: 1;
  &.inactive {
    opacity: 0.2;
  }
`;
const FilterSpacer = renderer_styles__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .ZP.div `
  width: 24px;
  flex-shrink: 0;
`;


/***/ }),

/***/ 58:
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   P: () => (/* binding */ makeSeries)
/* harmony export */ });
/* harmony import */ var common_util_navigation__WEBPACK_IMPORTED_MODULE_16__ = __webpack_require__(9471);
/* harmony import */ var main_net_errors__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(8383);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(7294);
/* harmony import */ var react_fast_compare__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(9590);
/* harmony import */ var react_fast_compare__WEBPACK_IMPORTED_MODULE_2___default = /*#__PURE__*/__webpack_require__.n(react_fast_compare__WEBPACK_IMPORTED_MODULE_2__);
/* harmony import */ var renderer_basics_EmptyState__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(7883);
/* harmony import */ var renderer_basics_ErrorState__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(3964);
/* harmony import */ var renderer_basics_FiltersContainer__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(4987);
/* harmony import */ var renderer_basics_Floater__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(3537);
/* harmony import */ var renderer_hocs_butlerCaller__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(5617);
/* harmony import */ var renderer_hocs_hook__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(2263);
/* harmony import */ var renderer_hocs_tab_utils__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(2250);
/* harmony import */ var renderer_hocs_withTab__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(2521);
/* harmony import */ var renderer_pages_common_ItemList__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(6797);
/* harmony import */ var renderer_pages_common_Page__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(9954);
/* harmony import */ var renderer_styles__WEBPACK_IMPORTED_MODULE_13__ = __webpack_require__(5836);
/* harmony import */ var renderer_t__WEBPACK_IMPORTED_MODULE_14__ = __webpack_require__(9080);
/* harmony import */ var underscore__WEBPACK_IMPORTED_MODULE_15__ = __webpack_require__(9050);

















const LoadMoreContainer = renderer_styles__WEBPACK_IMPORTED_MODULE_13__/* ["default"] */ .ZP.div `
  height: 200px;
  display: flex;
  align-items: center;
  justify-content: center;

  &:hover {
    cursor: pointer;
  }
`;
const LoadMoreText = renderer_styles__WEBPACK_IMPORTED_MODULE_13__/* ["default"] */ .ZP.div `
  font-size: ${(props) => props.theme.fontSizes.huge};
`;
const limit = 15;
function makeSeries(rc) {
    const Call = (0,renderer_hocs_butlerCaller__WEBPACK_IMPORTED_MODULE_7__/* ["default"] */ .ZP)(rc);
    const hasItems = (result) => {
        if (!result) {
            return false;
        }
        return !(0,underscore__WEBPACK_IMPORTED_MODULE_15__/* .isEmpty */ .xb)(result.items);
    };
    class NextPageButton extends react__WEBPACK_IMPORTED_MODULE_1__.PureComponent {
        constructor() {
            super(...arguments);
            this.loadNextPage = () => {
                const { cursor, loadNextPage } = this.props;
                loadNextPage(cursor);
            };
        }
        render() {
            const { gotLoadMore } = this.props;
            return (react__WEBPACK_IMPORTED_MODULE_1__.createElement(LoadMoreContainer, { ref: gotLoadMore, onClick: this.loadNextPage },
                react__WEBPACK_IMPORTED_MODULE_1__.createElement(LoadMoreText, null, "Load more...")));
        }
    }
    class SeriesPage extends react__WEBPACK_IMPORTED_MODULE_1__.PureComponent {
        constructor() {
            super(...arguments);
            this.renderCallContents = Call.renderCallback(({ result, loading, error }) => {
                return (react__WEBPACK_IMPORTED_MODULE_1__.createElement(react__WEBPACK_IMPORTED_MODULE_1__.Fragment, null,
                    this.renderError(result, error),
                    this.renderItems(result, loading),
                    this.renderNextPage(result, loading)));
            });
        }
        render() {
            const { params, cursor, limit, sequence } = this.props;
            return (react__WEBPACK_IMPORTED_MODULE_1__.createElement(Call, { errorsHandled: true, loadingHandled: true, params: Object.assign(Object.assign({}, params), { cursor, limit }), sequence: sequence, render: this.renderCallContents }));
        }
        renderNextPage(result, loading) {
            const { gotLoadMore, loadNextPage, isLast } = this.props;
            if (result && result.nextCursor && isLast) {
                return (react__WEBPACK_IMPORTED_MODULE_1__.createElement(NextPageButton, { cursor: result.nextCursor, gotLoadMore: gotLoadMore, loadNextPage: loadNextPage }));
            }
            if (!hasItems(result) && loading) {
                return (react__WEBPACK_IMPORTED_MODULE_1__.createElement(LoadMoreContainer, null,
                    react__WEBPACK_IMPORTED_MODULE_1__.createElement(renderer_basics_Floater__WEBPACK_IMPORTED_MODULE_6__/* ["default"] */ .Z, null)));
            }
            return null;
        }
        renderError(result, error) {
            if (!error) {
                return null;
            }
            if (hasItems(result) && (0,main_net_errors__WEBPACK_IMPORTED_MODULE_0__/* .isNetworkError */ .eE)(error)) {
                return null;
            }
            return react__WEBPACK_IMPORTED_MODULE_1__.createElement(renderer_basics_ErrorState__WEBPACK_IMPORTED_MODULE_4__/* ["default"] */ .Z, { error: error });
        }
        renderItems(result, loading) {
            if (!hasItems(result)) {
                if (loading) {
                    return null;
                }
                else {
                    return this.renderEmpty();
                }
            }
            const { items } = result;
            const { fallbackGetKey, getKey, getRecord, RecordComponent, extraProps, } = this.props;
            let doneSet = new Set();
            return (react__WEBPACK_IMPORTED_MODULE_1__.createElement(react__WEBPACK_IMPORTED_MODULE_1__.Fragment, null, items.map((item) => {
                const record = getRecord(item);
                if (!record) {
                    return null;
                }
                const key = getKey ? getKey(item) : fallbackGetKey(record);
                if (doneSet.has(key)) {
                    return null;
                }
                doneSet.add(key);
                return (react__WEBPACK_IMPORTED_MODULE_1__.createElement(RecordComponent, Object.assign({ key: key, item: item, record: record }, extraProps)));
            })));
        }
        renderEmpty() {
            return (react__WEBPACK_IMPORTED_MODULE_1__.createElement(renderer_basics_EmptyState__WEBPACK_IMPORTED_MODULE_3__/* ["default"] */ .Z, { bigText: (0,renderer_t__WEBPACK_IMPORTED_MODULE_14__._)("empty_state.nothing_to_see_here"), icon: "neutral" }));
        }
    }
    class Series extends react__WEBPACK_IMPORTED_MODULE_1__.PureComponent {
        constructor(props, context) {
            super(props, context);
            this.gotItemList = (itemList) => {
                this.itemList = itemList;
            };
            this.lastScrollTop = 0;
            this.onScroll = (0,underscore__WEBPACK_IMPORTED_MODULE_15__/* .throttle */ .P2)(() => {
                const { itemList } = this;
                if (!itemList) {
                    return;
                }
                const { scrollTop, scrollHeight, clientHeight } = itemList;
                if (scrollTop < this.lastScrollTop) {
                    if (this.restoreScrollInterval) {
                        console.log(`Cancelling scroll restore (scrolled up!)`);
                        clearInterval(this.restoreScrollInterval);
                        this.restoreScrollInterval = null;
                    }
                }
                this.lastScrollTop = scrollTop;
                const runwayLeft = scrollHeight - clientHeight - scrollTop;
                const shouldLoadMore = runwayLeft < 1200;
                const { loadMore } = this;
                if (shouldLoadMore && loadMore) {
                    loadMore.click();
                }
                (0,renderer_hocs_tab_utils__WEBPACK_IMPORTED_MODULE_9__/* .dispatchTabPageUpdate */ .pq)(this.props, { scrollTop });
            }, 100);
            this.gotLoadMore = (loadMore) => {
                this.loadMore = loadMore;
            };
            this.loadNextPage = (cursor) => {
                this.setState((state) => ({
                    cursors: [...state.cursors, cursor],
                }));
            };
            this.state = {
                cursors: [null],
                lastParams: null,
            };
            if (props.restoredScrollTop) {
                console.log(`Aiming for scrollTop ${props.restoredScrollTop}`);
                this.restoreScrollInterval = window.setInterval(() => {
                    if (this.itemList) {
                        this.itemList.scrollTop = props.restoredScrollTop;
                        const { scrollTop } = this.itemList;
                        if (scrollTop === props.restoredScrollTop) {
                            console.log(`Done adjusting, final scrollTop = ${scrollTop}`);
                            clearInterval(this.restoreScrollInterval);
                            this.restoreScrollInterval = null;
                        }
                    }
                }, 160);
            }
        }
        componentWillUnmount() {
            if (this.restoreScrollInterval) {
                clearInterval(this.restoreScrollInterval);
                this.restoreScrollInterval = null;
            }
        }
        static getDerivedStateFromProps(props, state) {
            if (!react_fast_compare__WEBPACK_IMPORTED_MODULE_2___default()(props.params, state.lastParams)) {
                return {
                    cursors: [null],
                    lastParams: props.params,
                };
            }
            return null;
        }
        getSnapshotBeforeUpdate(prevProps, prevState) {
            if (!react_fast_compare__WEBPACK_IMPORTED_MODULE_2___default()(this.props.params, prevProps.params)) {
                return {
                    resetScroll: true,
                };
            }
            return null;
        }
        componentDidUpdate(props, state, snapshot) {
            if (snapshot && snapshot.resetScroll && this.itemList) {
                console.log(`resetting scrollTop!`);
                this.itemList.scrollTop = 0;
                (0,renderer_hocs_tab_utils__WEBPACK_IMPORTED_MODULE_9__/* .dispatchTabPageUpdate */ .pq)(this.props, { scrollTop: 0 });
            }
        }
        componentDidMount() {
            const { label } = this.props;
            if (label) {
                (0,renderer_hocs_tab_utils__WEBPACK_IMPORTED_MODULE_9__/* .dispatchTabPageUpdate */ .pq)(this.props, { label });
            }
        }
        render() {
            const { params, sequence } = this.props;
            const { renderMainFilters = renderer_hocs_butlerCaller__WEBPACK_IMPORTED_MODULE_7__/* .renderNoop */ .a1, renderExtraFilters = renderer_hocs_butlerCaller__WEBPACK_IMPORTED_MODULE_7__/* .renderNoop */ .a1, fallbackGetKey, getKey, getRecord, RecordComponent, extraProps, } = this.props;
            const { cursors } = this.state;
            return (react__WEBPACK_IMPORTED_MODULE_1__.createElement(renderer_pages_common_Page__WEBPACK_IMPORTED_MODULE_12__/* ["default"] */ .Z, null,
                react__WEBPACK_IMPORTED_MODULE_1__.createElement(renderer_basics_FiltersContainer__WEBPACK_IMPORTED_MODULE_5__/* ["default"] */ .ZP, { loading: false }, renderMainFilters ? renderMainFilters() : null),
                renderExtraFilters ? renderExtraFilters() : null,
                react__WEBPACK_IMPORTED_MODULE_1__.createElement(renderer_pages_common_ItemList__WEBPACK_IMPORTED_MODULE_11__/* ["default"] */ .Z, { className: "series--itemlist", onScroll: this.onScroll, ref: this.gotItemList }, cursors.map((cursor, i) => (react__WEBPACK_IMPORTED_MODULE_1__.createElement(SeriesPage, { key: i, params: params, cursor: cursor, limit: limit, sequence: sequence, isLast: i === cursors.length - 1, gotLoadMore: this.gotLoadMore, loadNextPage: this.loadNextPage, fallbackGetKey: fallbackGetKey, getKey: getKey, getRecord: getRecord, RecordComponent: RecordComponent, extraProps: extraProps }))))));
        }
    }
    return (0,renderer_hocs_withTab__WEBPACK_IMPORTED_MODULE_10__/* .withTab */ .D1)((0,renderer_hocs_hook__WEBPACK_IMPORTED_MODULE_8__/* .hookWithProps */ .h)(Series)((map) => ({
        sequence: map((rs, props) => (0,common_util_navigation__WEBPACK_IMPORTED_MODULE_16__/* .ambientTab */ .mB)(rs, props).sequence),
        restoredScrollTop: map((rs, props) => (0,common_util_navigation__WEBPACK_IMPORTED_MODULE_16__/* .ambientPage */ .Jb)(rs, props).restoredScrollTop),
    }))(Series));
}


/***/ })

}]);
//# sourceMappingURL=645.chunk.js.map