"use strict";
(self["webpackChunkLIB"] = self["webpackChunkLIB"] || []).push([[758],{

/***/ 992:
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   Nd: () => (/* binding */ getRpcErrorData),
/* harmony export */   SS: () => (/* binding */ isInternalError),
/* harmony export */   dt: () => (/* binding */ getErrorStack),
/* harmony export */   mg: () => (/* binding */ asRequestError)
/* harmony export */ });
/* unused harmony export mergeLogAndError */
/* harmony import */ var common_logger__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(8976);
/* harmony import */ var common_format_datetime__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(1061);


function asRequestError(e) {
    const re = e;
    if (re.rpcError) {
        return e;
    }
    return null;
}
function getRpcErrorData(e) {
    const re = asRequestError(e);
    if (re && re.rpcError && re.rpcError.data) {
        return re.rpcError.data;
    }
    return null;
}
function isInternalError(e) {
    const re = asRequestError(e);
    if (!re) {
        return true;
    }
    if (re.rpcError.code < 0) {
        return true;
    }
    return false;
}
function getErrorStack(e) {
    if (!e) {
        return "Unknown error";
    }
    let errorStack = e.stack;
    const re = asRequestError(e);
    if (re) {
        const ed = getRpcErrorData(e);
        if (ed && ed.stack) {
            // use golang stack if available
            errorStack = ed.stack;
        }
        else if (re.message) {
            // or just message
            errorStack = re.message;
        }
    }
    return errorStack;
}
function mergeLogAndError(log, e) {
    let formattedLog = "";
    if (log) {
        let lines = log.split("\n");
        for (let line of lines) {
            line = line.trim();
            let fallback = false;
            try {
                const obj = JSON.parse(line);
                if (obj.msg) {
                    let date = formatDate(new Date(obj.time), "en-US", DATE_FORMAT);
                    let level = levels[obj.level];
                    let { msg } = obj;
                    formattedLog += `${date} [${level}] ${msg}\n`;
                }
                else {
                    fallback = true;
                }
            }
            catch (e) {
                fallback = true;
            }
            if (fallback) {
                formattedLog += `${line}\n`;
            }
        }
    }
    return `${formattedLog}\n\nError stack:\n${getErrorStack(e)}\n`;
}


/***/ }),

/***/ 3656:
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   Ip: () => (/* binding */ getDownloadError),
/* harmony export */   Z: () => (/* binding */ formatError),
/* harmony export */   dK: () => (/* binding */ getInstallPlanInfoError)
/* harmony export */ });
/* unused harmony export getButlerdErrorFromTuple */
/* harmony import */ var common_butlerd_errors__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(992);
/* harmony import */ var underscore__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(9050);


function formatError(e, apiErrorPrefix) {
    const re = (0,common_butlerd_errors__WEBPACK_IMPORTED_MODULE_0__/* .asRequestError */ .mg)(e);
    if (re && re.rpcError) {
        const { code, data } = re.rpcError;
        if (data && data.apiError && apiErrorPrefix) {
            const { messages } = data.apiError;
            const message = (0,underscore__WEBPACK_IMPORTED_MODULE_1__/* .first */ .Ps)(messages);
            if (message) {
                const snakeCaseMessage = message.replace(/\s/g, "_").toLowerCase();
                return [
                    `errors.api.${apiErrorPrefix}.${snakeCaseMessage}`,
                    {
                        defaultValue: `{message}`,
                        message,
                    },
                ];
            }
        }
        const { message } = re.rpcError;
        return [
            `butlerd.codes.${code}`,
            {
                defaultValue: `{message}`,
                message,
            },
        ];
    }
    return e.message;
}
function getDownloadError(item) {
    return getButlerdErrorFromTuple(item);
}
function getInstallPlanInfoError(item) {
    return getButlerdErrorFromTuple(item);
}
function getButlerdErrorFromTuple(item) {
    if (!item.errorMessage) {
        return null;
    }
    let rawError = new Error(item.errorMessage);
    rawError.stack = item.error;
    rawError.rpcError = {
        code: item.errorCode,
        message: item.errorMessage,
        data: {
            stack: item.error,
        },
    };
    return rawError;
}


/***/ }),

/***/ 5346:
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   $O: () => (/* binding */ formatUploadTitle),
/* harmony export */   A6: () => (/* binding */ formatBuildVersionInfo),
/* harmony export */   Pn: () => (/* binding */ formatUploadTitleFancy)
/* harmony export */ });
function formatUploadTitle(u) {
    return u ? u.displayName || u.filename : "?";
}
function clean(s) {
    return s
        .replace(/\.[a-zA-Z0-9]+$/, "")
        .replace(/[_-]/g, " ")
        .replace(/\s+/, " ");
}
function formatUploadTitleFancy(u) {
    if (u.displayName) {
        return u.displayName;
    }
    if (u.filename) {
        return clean(u.filename);
    }
    return "?";
}
function formatBuildVersionInfo(b) {
    if (!b) {
        return null;
    }
    if (b.userVersion) {
        return `v${b.userVersion}`;
    }
    return `#${b.version}`;
}


/***/ }),

/***/ 7883:
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   Z: () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(7294);
/* harmony import */ var renderer_basics_Button__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(6025);
/* harmony import */ var renderer_basics_Icon__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(4198);
/* harmony import */ var renderer_styles__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(5836);
/* harmony import */ var renderer_t__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(9080);





const EmptyStateDiv = renderer_styles__WEBPACK_IMPORTED_MODULE_3__/* ["default"] */ .ZP.div `
  color: ${(props) => props.theme.secondaryText};
  width: 100%;
  text-align: center;
  margin: 60px 0;

  .leader {
    display: inline-block;
    font-size: 170px;
    margin-bottom: 20px;
  }

  h1 {
    font-size: ${(props) => props.theme.fontSizes.enormous};
    font-weight: bold;
    margin-bottom: 10px;
  }

  h2 {
    font-size: ${(props) => props.theme.fontSizes.huge};
  }
`;
const ButtonContainer = renderer_styles__WEBPACK_IMPORTED_MODULE_3__/* ["default"] */ .ZP.div `
  margin: 20px;
  display: inline-block;
`;
const EmptyStateContainer = renderer_styles__WEBPACK_IMPORTED_MODULE_3__/* ["default"] */ .ZP.div `
  display: flex;
  width: 100%;
  height: 100%;
  align-items: center;
  overflow: hidden;
`;
class EmptyState extends react__WEBPACK_IMPORTED_MODULE_0__.PureComponent {
    render() {
        const { bigText, smallText, icon, buttonIcon, buttonText, buttonAction, componentAction, className, } = this.props;
        return (react__WEBPACK_IMPORTED_MODULE_0__.createElement(EmptyStateContainer, null,
            react__WEBPACK_IMPORTED_MODULE_0__.createElement(EmptyStateDiv, { className: className },
                react__WEBPACK_IMPORTED_MODULE_0__.createElement(renderer_basics_Icon__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .Z, { icon: icon, className: "leader" }),
                react__WEBPACK_IMPORTED_MODULE_0__.createElement("h1", null, (0,renderer_t__WEBPACK_IMPORTED_MODULE_4__.T)(bigText)),
                smallText ? react__WEBPACK_IMPORTED_MODULE_0__.createElement("h2", null, (0,renderer_t__WEBPACK_IMPORTED_MODULE_4__.T)(smallText)) : null,
                componentAction,
                buttonAction ? (react__WEBPACK_IMPORTED_MODULE_0__.createElement(react__WEBPACK_IMPORTED_MODULE_0__.Fragment, null,
                    react__WEBPACK_IMPORTED_MODULE_0__.createElement(ButtonContainer, null,
                        react__WEBPACK_IMPORTED_MODULE_0__.createElement(renderer_basics_Button__WEBPACK_IMPORTED_MODULE_1__/* ["default"] */ .Z, { icon: buttonIcon, primary: true, onClick: buttonAction }, (0,renderer_t__WEBPACK_IMPORTED_MODULE_4__.T)(buttonText))))) : null)));
    }
}
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (EmptyState);


/***/ }),

/***/ 7703:
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   Z: () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony import */ var tslib__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(655);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(7294);
/* harmony import */ var renderer_styles__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(5836);



const LinkSpan = renderer_styles__WEBPACK_IMPORTED_MODULE_1__/* ["default"] */ .ZP.span `
  ${renderer_styles__WEBPACK_IMPORTED_MODULE_1__/* .secondaryLink */ .CF};

  transition: color 0.4s;
  flex-shrink: 0.1;
  overflow-x: hidden;
  text-overflow: ellipsis;
`;
class Link extends react__WEBPACK_IMPORTED_MODULE_0__.PureComponent {
    render() {
        const _a = this.props, { label, children } = _a, restProps = (0,tslib__WEBPACK_IMPORTED_MODULE_2__/* .__rest */ ._T)(_a, ["label", "children"]);
        return (react__WEBPACK_IMPORTED_MODULE_0__.createElement(LinkSpan, Object.assign({}, restProps),
            label,
            children));
    }
}
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (Link);
class Props {
}


/***/ }),

/***/ 485:
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   Z: () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(4184);
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(classnames__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var common_actions__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(2448);
/* harmony import */ var common_helpers_get_game_status__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(945);
/* harmony import */ var common_util_action_for_game__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(1829);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(7294);
/* harmony import */ var renderer_basics_Button__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(6025);
/* harmony import */ var renderer_basics_Icon__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(4198);
/* harmony import */ var renderer_basics_IconButton__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(5391);
/* harmony import */ var renderer_basics_LoadingCircle__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(6785);
/* harmony import */ var renderer_t__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(9080);
/* harmony import */ var renderer_hocs_hook__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(2263);
/* harmony import */ var common_helpers_secret_click__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(4843);












class MainAction extends react__WEBPACK_IMPORTED_MODULE_4__.PureComponent {
    constructor() {
        super(...arguments);
        this.onClick = (e) => {
            e.stopPropagation();
            const { dispatch, game, status } = this.props;
            const { operation, update, cave, access } = status;
            if ((0,common_helpers_secret_click__WEBPACK_IMPORTED_MODULE_11__/* .isSecretClick */ .C)(e)) {
                if (cave) {
                    dispatch(common_actions__WEBPACK_IMPORTED_MODULE_1__/* .actions */ .N.viewCaveDetails({ caveId: cave.id }));
                }
                return;
            }
            if (operation) {
                if (operation.type === common_helpers_get_game_status__WEBPACK_IMPORTED_MODULE_2__/* .OperationType */ .C8.Download) {
                    dispatch(common_actions__WEBPACK_IMPORTED_MODULE_1__/* .actions */ .N.navigate({ wind: "root", url: "itch://downloads" }));
                }
                else if (operation.type === common_helpers_get_game_status__WEBPACK_IMPORTED_MODULE_2__/* .OperationType */ .C8.Task) {
                    if (operation.name === "launch") {
                        dispatch(common_actions__WEBPACK_IMPORTED_MODULE_1__/* .actions */ .N.forceCloseGameRequest({ game }));
                    }
                }
            }
            else if (cave) {
                if (update) {
                    dispatch(common_actions__WEBPACK_IMPORTED_MODULE_1__/* .actions */ .N.showGameUpdate({ update }));
                }
                else {
                    dispatch(common_actions__WEBPACK_IMPORTED_MODULE_1__/* .actions */ .N.queueGame({ game }));
                }
            }
            else {
                if (access === common_helpers_get_game_status__WEBPACK_IMPORTED_MODULE_2__/* .Access */ .Nv.None) {
                    dispatch(common_actions__WEBPACK_IMPORTED_MODULE_1__/* .actions */ .N.initiatePurchase({ game }));
                }
                else {
                    dispatch(common_actions__WEBPACK_IMPORTED_MODULE_1__/* .actions */ .N.queueGame({ game }));
                }
            }
        };
    }
    render() {
        const { wide } = this.props;
        const { cave, access, operation, update } = this.props.status;
        let translucent = false;
        let iconComponent;
        let icon;
        let label;
        let primary = false;
        if (operation) {
            const { type, progress } = operation;
            translucent = true;
            if (operation.paused) {
                iconComponent = react__WEBPACK_IMPORTED_MODULE_4__.createElement(renderer_basics_Icon__WEBPACK_IMPORTED_MODULE_6__/* ["default"] */ .Z, { icon: "stopwatch" });
            }
            else if (!operation.active) {
                iconComponent = react__WEBPACK_IMPORTED_MODULE_4__.createElement(renderer_basics_Icon__WEBPACK_IMPORTED_MODULE_6__/* ["default"] */ .Z, { icon: "stopwatch" });
            }
            else {
                iconComponent = (react__WEBPACK_IMPORTED_MODULE_4__.createElement(renderer_basics_LoadingCircle__WEBPACK_IMPORTED_MODULE_8__/* ["default"] */ .Z, { bare: true, wide: wide, progress: progress > 0 ? progress : 0.1 }));
            }
            if (type === common_helpers_get_game_status__WEBPACK_IMPORTED_MODULE_2__/* .OperationType */ .C8.Download) {
                if (operation.paused) {
                    label = ["grid.item.downloads_paused"];
                }
                else if (operation.active) {
                    label = ["grid.item.installing"];
                }
                else {
                    label = ["grid.item.queued"];
                }
            }
            else if (type === common_helpers_get_game_status__WEBPACK_IMPORTED_MODULE_2__/* .OperationType */ .C8.Task) {
                const { name, stage } = operation;
                if (name === "launch") {
                    if (stage === "prepare") {
                        label = ["grid.item.running.prepare"];
                    }
                    else if (stage === "clean") {
                        label = ["grid.item.running.clean"];
                    }
                    else {
                        label = ["grid.item.running"];
                    }
                }
                else if (name === "uninstall") {
                    label = ["grid.item.uninstalling"];
                }
                else if (name === "install-queue") {
                    label = ["grid.item.queueing"];
                }
                else {
                    label = ["grid.item.installing"];
                }
            }
        }
        else if (cave) {
            if (update) {
                label = ["grid.item.update"];
                icon = "star";
            }
            else {
                const action = (0,common_util_action_for_game__WEBPACK_IMPORTED_MODULE_3__/* .actionForGame */ .x)(this.props.game, cave);
                label = [`grid.item.${action}`];
                if (action === "open") {
                    icon = "folder-open";
                }
                else {
                    icon = "play2";
                }
                primary = true;
            }
        }
        else {
            if (access === common_helpers_get_game_status__WEBPACK_IMPORTED_MODULE_2__/* .Access */ .Nv.Demo || access === common_helpers_get_game_status__WEBPACK_IMPORTED_MODULE_2__/* .Access */ .Nv.Press) {
                label = ["grid.item.review"];
                icon = "install";
            }
            else if (access === common_helpers_get_game_status__WEBPACK_IMPORTED_MODULE_2__/* .Access */ .Nv.Pwyw ||
                access === common_helpers_get_game_status__WEBPACK_IMPORTED_MODULE_2__/* .Access */ .Nv.Free ||
                access === common_helpers_get_game_status__WEBPACK_IMPORTED_MODULE_2__/* .Access */ .Nv.Key ||
                access === common_helpers_get_game_status__WEBPACK_IMPORTED_MODULE_2__/* .Access */ .Nv.Edit) {
                label = ["grid.item.install"];
                icon = "install";
            }
            else {
                label = ["grid.item.buy_now"];
                icon = "shopping_cart";
            }
        }
        if (!label) {
            return null;
        }
        const { iconOnly, className } = this.props;
        if (iconOnly) {
            if (!iconComponent) {
                if (icon) {
                    iconComponent = react__WEBPACK_IMPORTED_MODULE_4__.createElement(renderer_basics_Icon__WEBPACK_IMPORTED_MODULE_6__/* ["default"] */ .Z, { icon: icon });
                }
            }
            return (react__WEBPACK_IMPORTED_MODULE_4__.createElement(renderer_basics_IconButton__WEBPACK_IMPORTED_MODULE_7__/* ["default"] */ .Z, { onClick: this.onClick, className: classnames__WEBPACK_IMPORTED_MODULE_0___default()(className, "main-action"), "data-game-id": this.props.game.id, icon: iconComponent, hint: label, hintPosition: "left" }));
        }
        return (react__WEBPACK_IMPORTED_MODULE_4__.createElement(renderer_basics_Button__WEBPACK_IMPORTED_MODULE_5__/* ["default"] */ .Z, { onClick: this.onClick, className: classnames__WEBPACK_IMPORTED_MODULE_0___default()(className, "main-action"), wide: wide, translucent: translucent, iconComponent: iconComponent, label: (0,renderer_t__WEBPACK_IMPORTED_MODULE_9__.T)(label), primary: primary, "data-game-id": this.props.game.id }));
    }
}
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ((0,renderer_hocs_hook__WEBPACK_IMPORTED_MODULE_10__/* .hook */ .z)()(MainAction));


/***/ }),

/***/ 326:
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {


// EXPORTS
__webpack_require__.d(__webpack_exports__, {
  Z: () => (/* binding */ basics_UploadIcon)
});

// EXTERNAL MODULE: ./src/common/format/filesize.ts
var filesize = __webpack_require__(5379);
// EXTERNAL MODULE: ./src/common/constants/platform-data.ts
var platform_data = __webpack_require__(105);
// EXTERNAL MODULE: ./src/common/butlerd/messages.ts
var messages = __webpack_require__(4713);
;// CONCATENATED MODULE: ./src/main/reactors/make-upload-button.ts



function makeUploadButton(upload, opts = { showSize: true }) {
    let label = `${upload.displayName || upload.filename}`;
    let tags = [];
    if (upload.size > 0 && opts.showSize) {
        tags.push({
            label: `${fileSize(upload.size)}`,
        });
    }
    if (upload.demo) {
        tags.push({
            label: ["pick_update_upload.tags.demo"],
        });
    }
    for (const prop of Object.keys(platformData)) {
        if (upload[prop]) {
            tags.push({
                icon: platformData[prop].icon,
            });
        }
    }
    const timeAgo = {
        date: upload.updatedAt,
    };
    const icon = uploadIcon(upload) || "download";
    return { label, tags, icon, timeAgo };
}
const uploadIcons = {
    [messages/* UploadType */.AJ.Default]: "gamepad",
    [messages/* UploadType */.AJ.Flash]: "neutral",
    [messages/* UploadType */.AJ.Unity]: "neutral",
    [messages/* UploadType */.AJ.Java]: "neutral",
    [messages/* UploadType */.AJ.HTML]: "html5",
    [messages/* UploadType */.AJ.Soundtrack]: "music",
    [messages/* UploadType */.AJ.Book]: "book",
    [messages/* UploadType */.AJ.Video]: "video",
    [messages/* UploadType */.AJ.Documentation]: "book",
    [messages/* UploadType */.AJ.Mod]: "shirt",
    [messages/* UploadType */.AJ.AudioAssets]: "file-music",
    [messages/* UploadType */.AJ.GraphicalAssets]: "images",
    [messages/* UploadType */.AJ.Sourcecode]: "code",
    [messages/* UploadType */.AJ.Other]: "zip",
};
function uploadIcon(upload) {
    return uploadIcons[upload.type];
}
// TODO: i18n that stuff
const uploadTypeHints = {
    [messages/* UploadType */.AJ.Default]: "File",
    [messages/* UploadType */.AJ.Flash]: "Flash embed",
    [messages/* UploadType */.AJ.Unity]: "Unity embed (legacy)",
    [messages/* UploadType */.AJ.Java]: "Java applet",
    [messages/* UploadType */.AJ.HTML]: "HTML5 app",
    [messages/* UploadType */.AJ.Soundtrack]: "Soundtrack",
    [messages/* UploadType */.AJ.Book]: "Book",
    [messages/* UploadType */.AJ.Video]: "Video",
    [messages/* UploadType */.AJ.Documentation]: "Documentation",
    [messages/* UploadType */.AJ.Mod]: "Mod",
    [messages/* UploadType */.AJ.AudioAssets]: "Audio assets",
    [messages/* UploadType */.AJ.GraphicalAssets]: "Graphical assets",
    [messages/* UploadType */.AJ.Sourcecode]: "Source code",
    [messages/* UploadType */.AJ.Other]: "Other",
};
function uploadTypeHint(upload) {
    return uploadTypeHints[upload.type];
}

// EXTERNAL MODULE: ./node_modules/react/index.js
var react = __webpack_require__(7294);
// EXTERNAL MODULE: ./src/renderer/basics/Icon.tsx
var Icon = __webpack_require__(4198);
;// CONCATENATED MODULE: ./src/renderer/basics/UploadIcon.tsx



class UploadIcon extends react.PureComponent {
    render() {
        const { upload } = this.props;
        if (!upload) {
            return null;
        }
        return react.createElement(Icon/* default */.Z, { icon: uploadIcon(upload), hint: uploadTypeHint(upload) });
    }
}
/* harmony default export */ const basics_UploadIcon = (UploadIcon);


/***/ }),

/***/ 7758:
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

// ESM COMPAT FLAG
__webpack_require__.r(__webpack_exports__);

// EXPORTS
__webpack_require__.d(__webpack_exports__, {
  "default": () => (/* binding */ pages_DownloadsPage)
});

// EXTERNAL MODULE: ./src/common/actions/index.ts
var actions = __webpack_require__(2448);
// EXTERNAL MODULE: ./src/main/reactors/downloads/getters.ts
var getters = __webpack_require__(9027);
// EXTERNAL MODULE: ./node_modules/react/index.js
var react = __webpack_require__(7294);
// EXTERNAL MODULE: ./src/renderer/basics/Button.tsx
var Button = __webpack_require__(6025);
// EXTERNAL MODULE: ./src/renderer/basics/EmptyState.tsx
var EmptyState = __webpack_require__(7883);
// EXTERNAL MODULE: ./src/renderer/basics/Link.tsx
var Link = __webpack_require__(7703);
// EXTERNAL MODULE: ./src/renderer/basics/LoadingCircle/index.tsx + 1 modules
var LoadingCircle = __webpack_require__(6785);
// EXTERNAL MODULE: ./src/renderer/hocs/hook.tsx
var hook = __webpack_require__(2263);
// EXTERNAL MODULE: ./src/renderer/hocs/tab-utils.tsx
var tab_utils = __webpack_require__(2250);
// EXTERNAL MODULE: ./src/renderer/hocs/withTab.tsx
var withTab = __webpack_require__(2521);
// EXTERNAL MODULE: ./src/renderer/pages/common/SortsAndFilters.tsx
var SortsAndFilters = __webpack_require__(7128);
// EXTERNAL MODULE: ./src/common/util/navigation.ts
var navigation = __webpack_require__(9471);
// EXTERNAL MODULE: ./src/renderer/basics/Cover/index.tsx + 2 modules
var Cover = __webpack_require__(103);
// EXTERNAL MODULE: ./src/renderer/basics/Filler.tsx
var Filler = __webpack_require__(4333);
// EXTERNAL MODULE: ./src/renderer/basics/TimeAgo.tsx + 2 modules
var TimeAgo = __webpack_require__(8923);
// EXTERNAL MODULE: ./src/renderer/helpers/whenClickNavigates.ts
var whenClickNavigates = __webpack_require__(9698);
// EXTERNAL MODULE: ./src/renderer/styles.ts
var styles = __webpack_require__(5836);
// EXTERNAL MODULE: ./src/renderer/t.tsx + 2 modules
var t = __webpack_require__(9080);
// EXTERNAL MODULE: ./src/common/format/upload.ts
var format_upload = __webpack_require__(5346);
;// CONCATENATED MODULE: ./src/renderer/pages/DownloadsPage/GameUpdateRow.tsx












const GameUpdateRowDiv = styles/* default */.ZP.div `
  flex-shrink: 0;
  line-height: 1.6;

  background-color: ${(props) => props.theme.itemBackground};

  display: flex;
  flex-direction: row;
  align-items: center;

  margin: 0.4em 0;
  padding: 0 4px;
  border-radius: 2px;
`;
const GameUpdateInfo = styles/* default */.ZP.div `
  margin: 0;
  padding: 8px;
`;
const GameUpdateControls = styles/* default */.ZP.div `
  margin: 0;
  padding: 8px;
`;
const GameCover = styles/* default */.ZP.div `
  flex-basis: 60px;
  padding: 8px;
`;
const GameTitle = styles/* default */.ZP.div `
  display: inline-block;
  font-weight: bold;
  cursor: pointer;
`;
const StyledTimeAgo = (0,styles/* default */.ZP)((0,TimeAgo/* default */.Z)) `
  color: ${(props) => props.theme.secondaryText};
`;
const VersionInfo = styles/* default */.ZP.div `
  color: ${(props) => props.theme.secondaryText};
`;
class GameUpdateRow extends react.PureComponent {
    constructor() {
        super(...arguments);
        this.onUpdate = () => {
            const { update, dispatch } = this.props;
            dispatch(actions/* actions */.N.showGameUpdate({ update }));
        };
        this.onNavigate = (e) => {
            const { update, dispatch } = this.props;
            const { game } = update;
            dispatch(actions/* actions */.N.navigate({
                wind: "root",
                url: (0,navigation/* urlForGame */.OH)(game.id),
                background: (0,whenClickNavigates/* doesEventMeanBackground */.$)(e),
            }));
        };
    }
    render() {
        const { update } = this.props;
        const { game } = update;
        const { upload, build } = update.choices[0];
        let updatedAt = build ? build.updatedAt : upload.updatedAt;
        let versionInfo = (0,format_upload/* formatBuildVersionInfo */.A6)(build);
        return (react.createElement(GameUpdateRowDiv, null,
            react.createElement(GameCover, null,
                react.createElement(Cover/* default */.ZP, { gameId: game.id, coverUrl: game.coverUrl, stillCoverUrl: game.stillCoverUrl, showGifMarker: false, onClick: this.onNavigate, hover: false })),
            react.createElement(GameUpdateInfo, null,
                react.createElement(GameTitle, { onClick: this.onNavigate }, game.title),
                react.createElement(VersionInfo, null,
                    versionInfo ? react.createElement(react.Fragment, null,
                        versionInfo,
                        " \u2014 ") : null,
                    react.createElement(StyledTimeAgo, { date: updatedAt }))),
            react.createElement(Filler/* default */.Z, null),
            react.createElement(GameUpdateControls, null,
                react.createElement(Link/* default */.Z, { label: (0,t.T)(["pick_update_upload.buttons.update"]), onClick: this.onUpdate }))));
    }
}
/* harmony default export */ const DownloadsPage_GameUpdateRow = ((0,hook/* hook */.z)()(GameUpdateRow));

// EXTERNAL MODULE: ./node_modules/classnames/index.js
var classnames = __webpack_require__(4184);
var classnames_default = /*#__PURE__*/__webpack_require__.n(classnames);
// EXTERNAL MODULE: ./src/common/format/errors.ts
var errors = __webpack_require__(3656);
// EXTERNAL MODULE: ./src/common/format/operation.ts
var operation = __webpack_require__(5414);
// EXTERNAL MODULE: ./src/common/helpers/get-game-status.ts + 1 modules
var get_game_status = __webpack_require__(945);
// EXTERNAL MODULE: ./src/renderer/modals.ts + 3 modules
var modals = __webpack_require__(9088);
// EXTERNAL MODULE: ./node_modules/polished/dist/polished.esm.js + 9 modules
var polished_esm = __webpack_require__(6538);
// EXTERNAL MODULE: ./src/renderer/basics/DownloadProgressSpan.tsx
var DownloadProgressSpan = __webpack_require__(830);
// EXTERNAL MODULE: ./src/renderer/basics/IconButton.tsx
var IconButton = __webpack_require__(5391);
// EXTERNAL MODULE: ./src/renderer/basics/MainAction.tsx
var MainAction = __webpack_require__(485);
// EXTERNAL MODULE: ./src/renderer/basics/UploadIcon.tsx + 1 modules
var UploadIcon = __webpack_require__(326);
// EXTERNAL MODULE: ./src/renderer/hocs/withHover.tsx + 1 modules
var withHover = __webpack_require__(7628);
// EXTERNAL MODULE: ./node_modules/react-container-dimensions/lib/index.js
var lib = __webpack_require__(6259);
;// CONCATENATED MODULE: ./src/renderer/pages/DownloadsPage/Chart.tsx



const ChartWrapper = styles/* default */.ZP.div `
  position: absolute;
  top: 0;
  bottom: 0;
  left: 0;
  right: 0;
  pointer-events: none;
`;
class ChartGradient extends react.PureComponent {
    render() {
        return (react.createElement("linearGradient", { id: "downloadGradient", x1: "0", x2: "0", y1: "0", y2: "1" },
            react.createElement("stop", { offset: "0%", stopColor: "rgb(158, 150, 131)", stopOpacity: "0.2" }),
            react.createElement("stop", { offset: "50%", stopColor: "rgb(158, 150, 131)", stopOpacity: "0.2" }),
            react.createElement("stop", { offset: "100%", stopColor: "rgb(158, 150, 131)", stopOpacity: "0.1" })));
    }
}
class Chart extends react.PureComponent {
    constructor() {
        super(...arguments);
        this.renderContent = ({ width, height }) => {
            const { data } = this.props;
            let clipPathId = "clipPath" + Date.now();
            let max = 10; // enforce a minimum so we don't get NaNs
            for (const point of data) {
                if (point > max) {
                    max = point;
                }
            }
            max *= 1.1;
            const xs = width / (data.length - 1);
            const ys = height / max;
            let pathString = `M0,${height}`;
            for (let x = 0; x < data.length; x++) {
                let y = data[x];
                pathString += `L${x * xs},${height - y * ys}`;
            }
            pathString += `L${data.length * xs},${height}`;
            pathString += `L0,${height}`;
            pathString += "Z";
            return (react.createElement("svg", { width: width, height: height, version: "1.1", viewBox: `0 0 ${width} ${height}` },
                react.createElement("defs", null,
                    react.createElement("clipPath", { id: clipPathId },
                        react.createElement("rect", { width: width, height: height, x: 0, y: 0 })),
                    react.createElement(ChartGradient, null)),
                react.createElement("g", { clipPath: `#${clipPathId}` },
                    react.createElement("path", { d: pathString, fill: "url(#downloadGradient)", height: height, width: width, stroke: "none" }))));
        };
    }
    render() {
        return (react.createElement(ChartWrapper, null,
            react.createElement(lib/* default */.Z, null, this.renderContent)));
    }
}
/* harmony default export */ const DownloadsPage_Chart = (Chart);

// EXTERNAL MODULE: ./src/renderer/pages/PageStyles/games.tsx
var games = __webpack_require__(465);
;// CONCATENATED MODULE: ./src/renderer/pages/DownloadsPage/Row.tsx


























const TitleCompact = (0,styles/* default */.ZP)((0,games/* Title */.Dx)) `
  font-size: ${(props) => props.theme.fontSizes.larger};
  padding-bottom: 0.2em;
`;
const DownloadRowDiv = styles/* default */.ZP.div `
  font-size: ${(props) => props.theme.fontSizes.large};
  position: relative;

  border: 1px solid transparent;
  transition: all 0.4s;

  background-color: ${(props) => props.theme.inputBackground};
  margin: 14px 0;

  &.first {
    padding-bottom: 4px;
  }

  &.has-operation {
    background-color: ${(props) => (0,polished_esm/* lighten */.$n)(0.05, props.theme.inputBackground)};
    border-color: ${(props) => (0,polished_esm/* lighten */.$n)(0.2, props.theme.inputBackground)};
  }

  display: flex;
  flex-direction: row;
  align-items: center;

  .stats {
    flex-grow: 1;
  }

  .stats--control {
    .control-title,
    .control--details {
      white-space: nowrap;
      max-width: 500px;
      text-overflow: ellipsis;
    }

    .control--details,
    .control--status {
      font-size: ${(props) => props.theme.fontSizes.baseText};

      display: flex;
      flex-direction: row;
      align-items: center;

      padding: 0.1em 0;
      padding-top: 0.4em;
    }

    .control--error {
      padding: 0.1em 0;
      line-height: 1.4;

      max-width: 500px;

      color: ${(props) => props.theme.baseColors.carnation};
    }

    .control--details {
      color: ${(props) => props.theme.secondaryText};
    }

    .progress {
      ${styles/* progress */.YD};

      position: absolute;
      left: 0;
      right: 0;
      bottom: 0;
      height: 4px;

      overflow: hidden;
      &,
      .progress-inner {
        border-radius: 5px;
      }
      .progress-inner.indeterminate {
        animation: ${styles/* animations */.sF.horizontalIndeterminate} 2.4s ease-in-out
          infinite;
      }
    }
  }

  &:not(.first) {
    .progress {
      display: none;
    }
  }
`;
const Row_Filler = styles/* default */.ZP.div `
  flex-grow: 1;
`;
const Spacer = styles/* default */.ZP.div `
  height: 1px;
  min-width: 8px;
`;
const coverFactor = 1.2;
const coverStyle = () => (0,styles/* css */.iv) `
  flex-shrink: 0;
  width: ${105 * coverFactor}px;
  height: ${80 * coverFactor}px;
  padding-bottom: 0;

  margin-right: 16px;
  box-shadow: 0 0 20px rgba(0, 0, 0, 0.4);
`;
const StyledCover = (0,styles/* default */.ZP)((0,Cover/* default */.ZP)) `
  ${coverStyle()};

  &.hasError {
    filter: grayscale(100%);
  }
`;
const Controls = styles/* default */.ZP.div `
  display: flex;
  flex-direction: row;
  align-items: center;
  padding-left: 8px;
  padding-right: 8px;
`;
class DownloadRow extends react.PureComponent {
    constructor(props, context) {
        super(props, context);
        this.onCoverContextMenu = (ev) => {
            ev.preventDefault();
            const { item, dispatch } = this.props;
            const { game } = item;
            dispatch(actions/* actions */.N.openGameContextMenu({
                game,
                wind: (0,navigation/* ambientWind */.w)(),
                clientX: ev.clientX,
                clientY: ev.pageY,
            }));
        };
        this.onNavigate = (ev) => {
            const { item, dispatch } = this.props;
            if (ev.shiftKey && ev.ctrlKey) {
                dispatch(actions/* actions */.N.openModal(modals/* default */.Z.exploreJson.make({
                    wind: "root",
                    title: "Download data",
                    message: "",
                    widgetParams: {
                        data: item,
                    },
                })));
                return;
            }
            const background = (0,whenClickNavigates/* doesEventMeanBackground */.$)(ev);
            const { game } = item;
            dispatch(actions/* actions */.N.navigate({
                wind: "root",
                url: (0,navigation/* urlForGame */.OH)(game.id),
                background,
            }));
        };
        this.onDiscard = () => {
            const { id } = this.props.item;
            const { dispatch } = this.props;
            dispatch(actions/* actions */.N.discardDownload({ id }));
        };
        this.onPrioritize = () => {
            const { id } = this.props.item;
            const { dispatch } = this.props;
            dispatch(actions/* actions */.N.prioritizeDownload({ id }));
        };
        this.onShowError = (ev) => {
            ev.stopPropagation();
            const { id } = this.props.item;
            const { dispatch } = this.props;
            dispatch(actions/* actions */.N.showDownloadError({ id }));
        };
        this.state = {};
    }
    render() {
        const { first, finished, item, speeds } = this.props;
        const { game } = item;
        const { coverUrl, stillCoverUrl } = game;
        const itemClasses = classnames_default()("download-row-item", {
            first,
            dimmed: !finished && !first,
            finished,
            ["has-operation"]: !!this.props.status.operation,
        });
        const { hover, onMouseEnter, onMouseLeave } = this.props;
        return (react.createElement(DownloadRowDiv, { className: itemClasses, "data-game-id": item.game.id, onContextMenu: this.onCoverContextMenu, onMouseEnter: onMouseEnter, onMouseLeave: onMouseLeave },
            first ? react.createElement(DownloadsPage_Chart, { data: speeds }) : null,
            react.createElement(StyledCover, { hover: hover, coverUrl: coverUrl, stillCoverUrl: stillCoverUrl, gameId: game.id, onClick: this.onNavigate, className: classnames_default()({ hasError: !!item.error }) }),
            react.createElement("div", { className: "stats" }, this.progress()),
            this.controls()));
    }
    controls() {
        const { first, status, item } = this.props;
        if (!status.operation && item.error) {
            return (react.createElement(Controls, null,
                react.createElement(Button/* default */.Z, { label: (0,t.T)(["grid.item.view_details"]), onClick: this.onShowError })));
        }
        let showPrioritize = !item.finishedAt && !first;
        let showMainAction = !status.operation || status.operation.type !== get_game_status/* OperationType */.C8.Download;
        return (react.createElement(Controls, null,
            showPrioritize ? (react.createElement(IconButton/* default */.Z, { big: true, hint: (0,t._)("grid.item.prioritize_download"), icon: "caret-up", onClick: this.onPrioritize })) : null,
            showMainAction ? (react.createElement(react.Fragment, null,
                react.createElement(MainAction/* default */.Z, { game: item.game, status: status, caveId: item.caveId }),
                react.createElement(Spacer, null))) : null,
            react.createElement(IconButton/* default */.Z, { big: true, hintPosition: "left", hint: (0,t._)("grid.item.discard_download"), icon: "cross", onClick: this.onDiscard })));
    }
    progress() {
        const { first, finished, status, downloadsPaused } = this.props;
        const { operation } = status;
        if (finished) {
            return (react.createElement("div", { className: "stats--control" },
                this.renderTitle(),
                this.renderDetails(),
                this.renderErrorOrTimestamp()));
        }
        const { progress = 0, bps, eta } = status.operation;
        const progressInnerStyle = {};
        const positiveProgress = progress > 0;
        const hasNonDownloadTask = operation && operation.type !== get_game_status/* OperationType */.C8.Download;
        const indeterminate = (first || hasNonDownloadTask) && !downloadsPaused && !positiveProgress;
        if (indeterminate) {
            progressInnerStyle.width = `${100 / 3}%`;
        }
        else {
            progressInnerStyle.width = `${progress * 100}%`;
        }
        if (this.props.downloadsPaused) {
            progressInnerStyle.filter = "grayscale(100%)";
        }
        return (react.createElement("div", { className: "stats--control" },
            this.renderTitle(),
            this.renderDetails(),
            react.createElement("div", { className: "progress" },
                react.createElement("div", { className: classnames_default()("progress-inner", {
                        indeterminate,
                    }), style: progressInnerStyle })),
            react.createElement("div", { className: "control--status" },
                this.renderStatus(),
                react.createElement(Row_Filler, null),
                react.createElement(react.Fragment, null, !operation.paused && first && eta >= 0 && bps ? (react.createElement(react.Fragment, null,
                    react.createElement(Spacer, null),
                    react.createElement(DownloadProgressSpan/* default */.Z, { eta: eta, bps: bps, downloadsPaused: operation.paused }))) : null))));
    }
    renderTitle() {
        const { game } = this.props.item;
        return (react.createElement(react.Fragment, null,
            react.createElement(TitleCompact, { className: "control--title" },
                react.createElement("a", { href: (0,navigation/* urlForGame */.OH)(game.id) }, game.title)),
            react.createElement(Row_Filler, null)));
    }
    renderDetails() {
        return react.createElement("div", { className: "control--details" }, this.renderUpload());
    }
    renderErrorOrTimestamp() {
        const { error, finishedAt, reason } = this.props.item;
        if (!error) {
            const outcomeText = (0,operation/* formatOutcome */.vm)(reason);
            return (react.createElement("div", { className: "control--status" },
                react.createElement(TimeAgo/* default */.Z, { date: finishedAt }),
                outcomeText ? (react.createElement(react.Fragment, null,
                    react.createElement(Spacer, null),
                    "—",
                    react.createElement(Spacer, null),
                    (0,t.T)(outcomeText))) : null));
        }
        return (react.createElement("div", { className: "control--error" },
            (0,t.T)(["prompt.install_error.title"]),
            " ",
            (0,t.T)((0,errors/* formatError */.Z)((0,errors/* getDownloadError */.Ip)(this.props.item)))));
    }
    renderUpload() {
        const { item } = this.props;
        const { upload } = item;
        return (react.createElement(react.Fragment, null,
            react.createElement(UploadIcon/* default */.Z, { upload: upload }),
            react.createElement(Spacer, null),
            (0,format_upload/* formatUploadTitle */.$O)(upload)));
    }
    renderStatus() {
        const { status, first } = this.props;
        const { operation } = status;
        if (operation.paused || !first) {
            return (0,t.T)(["grid.item.queued"]);
        }
        return this.formatOperation(operation);
    }
    formatOperation(op) {
        if (op.type === get_game_status/* OperationType */.C8.Download) {
            const { item } = this.props;
            const reasonText = (0,operation/* formatReason */.DY)(op.reason);
            return (react.createElement(react.Fragment, null,
                react.createElement(TimeAgo/* default */.Z, { before: (0,t.T)(["download.started"]), date: new Date(item.startedAt) }),
                reasonText ? (react.createElement(react.Fragment, null,
                    react.createElement(Spacer, null),
                    "—",
                    react.createElement(Spacer, null),
                    (0,t.T)(reasonText))) : ("")));
        }
        return (react.createElement(react.Fragment, null,
            react.createElement(LoadingCircle/* default */.Z, { progress: op.progress }),
            (0,t.T)((0,operation/* formatOperation */.de)(op))));
    }
}
/* harmony default export */ const Row = ((0,withHover/* default */.Z)((0,hook/* hookWithProps */.h)(DownloadRow)((map) => ({
    speeds: map((rs) => rs.downloads.speeds),
    downloadsPaused: map((rs) => rs.downloads.paused),
    status: map((rs, props) => (0,get_game_status/* default */.ZP)(rs, props.item.game, props.item.caveId)),
}))(DownloadRow)));

// EXTERNAL MODULE: ./node_modules/underscore/modules/index-all.js + 160 modules
var index_all = __webpack_require__(9050);
;// CONCATENATED MODULE: ./src/renderer/pages/DownloadsPage/index.tsx

















const PauseResumeButton = (0,styles/* default */.ZP)((0,Button/* default */.Z)) `
  min-width: 210px;
`;
const DownloadsDiv = styles/* default */.ZP.div `
  ${styles/* meat */.pw};
`;
const DownloadsContentDiv = styles/* default */.ZP.div `
  overflow-y: auto;
  padding: 0 20px 20px 10px;
  padding-top: 15px;
  position: relative;

  .global-controls {
    float: right;
  }

  .section-bar {
    display: flex;
    flex-direction: row;
    align-items: center;
    margin: 20px 0 20px 10px;
    flex-shrink: 0;

    .spacer {
      height: 1px;
      width: 1em;
    }

    .filler {
      flex-grow: 1;
    }

    .clear {
      margin-left: 8px;
      ${styles/* clickable */.Zk};
    }
  }

  .game-actions .main-action {
    padding: 3px 10px;
  }
`;
class DownloadsPage extends react.PureComponent {
    constructor() {
        super(...arguments);
        this.visitFeatured = () => {
            const { dispatch } = this.props;
            dispatch(actions/* actions */.N.navigate({ wind: "root", url: "itch://featured" }));
        };
        this.onTogglePause = () => {
            const { downloadsPaused, dispatch } = this.props;
            dispatch(actions/* actions */.N.setDownloadsPaused({ paused: !downloadsPaused }));
        };
        this.clearFinishedDownloads = () => {
            const { dispatch } = this.props;
            dispatch(actions/* actions */.N.clearFinishedDownloads({}));
        };
        this.onUpdateAll = () => {
            const { dispatch } = this.props;
            dispatch(actions/* actions */.N.queueAllGameUpdates({}));
        };
    }
    componentDidMount() {
        (0,tab_utils/* dispatchTabPageUpdate */.pq)(this.props, {
            label: ["sidebar.downloads"],
        });
    }
    render() {
        return react.createElement(DownloadsDiv, null, this.renderContents());
    }
    renderContents() {
        const { items, finishedItems, updates, dispatch } = this.props;
        const allEmpty = (0,index_all/* isEmpty */.xb)(items) && (0,index_all/* isEmpty */.xb)(finishedItems) && (0,index_all/* isEmpty */.xb)(updates);
        if (allEmpty) {
            return (react.createElement(DownloadsContentDiv, null,
                this.renderControls(),
                react.createElement(EmptyState/* default */.Z, { className: "no-active-downloads", icon: "download", bigText: (0,t._)("status.downloads.no_active_downloads"), smallText: (0,t._)("status.downloads.no_active_downloads_subtext"), buttonIcon: "earth", buttonText: (0,t._)("status.downloads.find_games_button"), buttonAction: this.visitFeatured })));
        }
        const firstItem = (0,index_all/* first */.Ps)(items);
        const queuedItems = (0,index_all/* rest */.RF)(items);
        return (react.createElement(DownloadsContentDiv, null,
            this.renderControls(),
            this.renderFirstItem(firstItem),
            this.renderQueuedItems(queuedItems),
            this.renderRecentActivity(),
            this.renderUpdates()));
    }
    renderFirstItem(firstItem) {
        if (!firstItem) {
            return null;
        }
        return (react.createElement(react.Fragment, null,
            react.createElement("div", { className: "section-bar" },
                react.createElement(games/* Title */.Dx, null, (0,t.T)(["status.downloads.category.active"]))),
            react.createElement(Row, { key: firstItem.id, item: firstItem, first: true })));
    }
    renderQueuedItems(queuedItems) {
        if ((0,index_all/* isEmpty */.xb)(queuedItems)) {
            return null;
        }
        return (react.createElement(react.Fragment, null,
            react.createElement("div", { className: "section-bar" },
                react.createElement(games/* Title */.Dx, null, (0,t.T)(["status.downloads.category.queued"]))),
            (0,index_all/* map */.UI)(queuedItems, (item, i) => (react.createElement(Row, { key: item.id, item: item })))));
    }
    renderUpdates() {
        const { updates, updateCheckHappening, updateCheckProgress } = this.props;
        if ((0,index_all/* isEmpty */.xb)(updates) && !updateCheckHappening) {
            return null;
        }
        return (react.createElement(react.Fragment, null,
            react.createElement("div", { className: "section-bar" },
                react.createElement(games/* Title */.Dx, { className: "finished-header" },
                    react.createElement("span", null,
                        (0,t.T)(["status.downloads.updates_available"]),
                        " (",
                        (0,index_all/* size */.dp)(updates),
                        ")")),
                react.createElement(SortsAndFilters/* FilterSpacer */.dz, null),
                react.createElement(Link/* default */.Z, { label: (0,t.T)(["status.downloads.update_all"]), onClick: this.onUpdateAll }),
                updateCheckHappening ? (react.createElement(react.Fragment, null,
                    react.createElement("div", { className: "spacer" }),
                    react.createElement(LoadingCircle/* default */.Z, { progress: updateCheckProgress }))) : null),
            (0,index_all/* map */.UI)(updates, (update, k) => (react.createElement(DownloadsPage_GameUpdateRow, { key: k, update: update })))));
    }
    renderControls() {
        return (react.createElement(react.Fragment, null,
            react.createElement("div", { className: "global-controls" }, this.props.downloadsPaused ? (react.createElement(PauseResumeButton, { icon: "triangle-right", onClick: this.onTogglePause }, (0,t.T)(["status.downloads.resume_downloads"]))) : (react.createElement(PauseResumeButton, { icon: "pause", onClick: this.onTogglePause }, (0,t.T)(["status.downloads.pause_downloads"]))))));
    }
    renderRecentActivity() {
        const { finishedItems, dispatch } = this.props;
        if ((0,index_all/* isEmpty */.xb)(finishedItems)) {
            return null;
        }
        return (react.createElement(react.Fragment, null,
            react.createElement("div", { key: "finished-header", className: "section-bar" },
                react.createElement(games/* Title */.Dx, { className: "finished-header" }, (0,t.T)(["status.downloads.category.recent_activity"])),
                react.createElement(SortsAndFilters/* FilterSpacer */.dz, null),
                react.createElement(Link/* default */.Z, { className: "downloads-clear-all", onClick: this.clearFinishedDownloads }, (0,t.T)(["status.downloads.clear_all_finished"]))),
            (0,index_all/* map */.UI)(finishedItems, (item) => (react.createElement(Row, { key: item.id, item: item, finished: true })))));
    }
}
/* harmony default export */ const pages_DownloadsPage = ((0,withTab/* withTab */.D1)((0,hook/* hook */.z)((map) => ({
    items: map((rs) => (0,getters/* getPendingDownloads */.g2)(rs.downloads)),
    finishedItems: map((rs) => (0,getters/* getFinishedDownloads */.po)(rs.downloads)),
    updates: map((rs) => rs.gameUpdates.updates),
    updateCheckHappening: map((rs) => rs.gameUpdates.checking),
    updateCheckProgress: map((rs) => rs.gameUpdates.progress),
    downloadsPaused: map((rs) => rs.downloads.paused),
}))(DownloadsPage)));


/***/ }),

/***/ 7128:
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   Ni: () => (/* binding */ FilterOptionButton),
/* harmony export */   Zk: () => (/* binding */ FilterOptionIcon),
/* harmony export */   dz: () => (/* binding */ FilterSpacer),
/* harmony export */   e_: () => (/* binding */ FilterGroup),
/* harmony export */   gY: () => (/* binding */ SortsAndFilters),
/* harmony export */   zR: () => (/* binding */ FilterOptionLink)
/* harmony export */ });
/* harmony import */ var renderer_basics_FiltersContainer__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(4987);
/* harmony import */ var renderer_basics_Icon__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(4198);
/* harmony import */ var renderer_styles__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(5836);



const SortsAndFilters = (0,renderer_styles__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .ZP)((0,renderer_basics_FiltersContainer__WEBPACK_IMPORTED_MODULE_0__/* .FiltersContainerDiv */ .vN)) `
  display: flex;
  justify-content: center;
  flex-flow: row wrap;
  height: auto;

  padding: 0.4em 0.6em;
  font-weight: normal;
`;
const FilterGroup = renderer_styles__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .ZP.div `
  margin: 0.5em 0;
  display: flex;
  flex-flow: row wrap;
`;
// const inactiveBg = `linear-gradient(to top,hsla(355, 43%, 25%, 1),hsla(355, 43%, 17%, 1))`;
// const activeBg = `linear-gradient(to top, hsla(355, 43%, 50%, 1), hsla(355, 43%, 37%, 1));`;
const inactiveBg = `linear-gradient(to top,hsla(355, 43%, 17%, 1),hsla(355, 43%, 11%, 1))`;
const activeBg = `linear-gradient(to top, hsla(355, 43%, 33%, 1), hsla(355, 43%, 22%, 1));`;
const borderColor = `#843442`;
const borderRadius = `4px`;
const optionButtonLike = (0,renderer_styles__WEBPACK_IMPORTED_MODULE_2__/* .css */ .iv) `
  display: flex;
  flex-flow: row;
  align-items: center;

  background: ${inactiveBg};
  padding: 0.5em 1em;
  margin: 0;
  border: 1px solid ${borderColor};
  border-left: none;
  color: ${(props) => props.theme.baseText};
  transition: all 0.4s;

  &:first-child {
    border-radius: ${borderRadius} 0 0 ${borderRadius};
    border-left: 1px solid ${borderColor};
  }

  &:last-child {
    border-radius: 0 ${borderRadius} ${borderRadius} 0;
  }

  &:first-child:last-child {
    border-radius: ${borderRadius};
  }

  &.active {
    background: ${activeBg};
    color: ${(props) => props.theme.baseText};
  }

  &:hover {
    cursor: pointer;
  }
`;
const FilterOptionLink = renderer_styles__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .ZP.a `
  ${optionButtonLike};

  &.disabled {
    pointer-events: none;
    opacity: 0.4;
  }
`;
const FilterOptionButton = renderer_styles__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .ZP.div `
  ${optionButtonLike};
`;
const FilterOptionIcon = (0,renderer_styles__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .ZP)((0,renderer_basics_Icon__WEBPACK_IMPORTED_MODULE_1__/* ["default"] */ .Z)) `
  margin-right: 0.5em;
  font-size: 80%;

  opacity: 1;
  &.inactive {
    opacity: 0.2;
  }
`;
const FilterSpacer = renderer_styles__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .ZP.div `
  width: 24px;
  flex-shrink: 0;
`;


/***/ })

}]);
//# sourceMappingURL=758.chunk.js.map