"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.trimProperties = exports.trimProperty = exports.preventDoubleInitialization = void 0;
// We use this variable to store a stack trace of where the middleware
// is first initialized, to assist in debugging if someone accidentally enables
// it twice. This can easily be caused by importing files that are shared between
// the main and renderer processes.
let previouslyInitialized;
const preventDoubleInitialization = () => {
    if (previouslyInitialized) {
        // eslint-disable-next-line no-console
        console.error(new Error('electron-redux has already been attached to a store'));
        throw previouslyInitialized;
    }
    // We are intentionally not actually throwing the error here, we just
    // want to capture the call stack.
    previouslyInitialized = new Error('electron-redux was previously attached to a store here');
};
exports.preventDoubleInitialization = preventDoubleInitialization;
/**
 * Removes the property prop from the given object. Think of it as an actual
 * runtime implementation of the TypeScript Omit<T, K> type.
 */
const trimProperty = (prop, obj) => {
    return Object.fromEntries(Object.entries(obj).filter(([key]) => key !== prop));
};
exports.trimProperty = trimProperty;
/**
 * Removes multiple properties from the given object.
 */
const trimProperties = (props, obj) => {
    return Object.fromEntries(Object.entries(obj).filter(([key]) => !props.includes(key)));
};
exports.trimProperties = trimProperties;
