"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.syncMain = void 0;
const electron_1 = require("electron");
const redux_1 = require("redux");
const helpers_1 = require("../helpers");
const middleware = (store) => {
    electron_1.ipcMain.handle('electron-redux.FETCH_STATE', () => {
        // Stringify the current state, and freeze it to preserve certain types
        // that you might want to use in your state, but aren't JSON serializable
        // by default.
        return Promise.resolve(JSON.stringify(store.getState(), helpers_1.freeze));
    });
    // When receiving an action from a renderer
    electron_1.ipcMain.on('ACTION', (event, action) => {
        const localAction = helpers_1.stopForwarding(action);
        store.dispatch(localAction);
        // Forward it to all of the other renderers
        electron_1.webContents.getAllWebContents().forEach((contents) => {
            // Ignore the renderer that sent the action
            if (contents.id !== event.sender.id) {
                contents.send('ACTION', localAction);
            }
        });
    });
    return (next) => (action) => {
        if (helpers_1.validateAction(action)) {
            electron_1.webContents.getAllWebContents().forEach((contents) => {
                contents.send('ACTION', action);
            });
        }
        return next(action);
    };
};
const syncMain = (createStore) => {
    helpers_1.preventDoubleInitialization();
    return (reducer, state) => {
        return createStore(reducer, state, redux_1.applyMiddleware(middleware));
    };
};
exports.syncMain = syncMain;
