"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.syncRenderer = void 0;
const redux_1 = require("redux");
const helpers_1 = require("../helpers");
/**
 * Creates an action that will replace the current state with the provided
 * state. The scope is set to local in this creator function to make sure it is
 * never forwarded.
 */
const replaceState = (state) => ({
    type: 'electron-redux.REPLACE_STATE',
    payload: state,
    meta: { scope: 'local' },
});
const wrapReducer = (reducer) => (state, action) => {
    console.log('renderer reducer', action);
    switch (action.type) {
        case 'electron-redux.REPLACE_STATE':
            return action.payload;
        default:
            return reducer(state, action);
    }
};
const middleware = (store) => {
    __ElectronReduxBridge.subscribeToActions(store);
    return (next) => (action) => {
        console.log('renderer middleware', action);
        if (helpers_1.validateAction(action)) {
            console.log('validated action', action);
            __ElectronReduxBridge.sendAction(action);
        }
        return next(action);
    };
};
const syncRenderer = (createStore) => {
    helpers_1.preventDoubleInitialization();
    if (typeof __ElectronReduxBridge === 'undefined') {
        throw new Error('This renderer process is not properly configured. Did you import @goosewobbler/electron-redux/preload in your preload script?');
    }
    return (reducer, state) => {
        const store = createStore(wrapReducer(reducer), state, redux_1.applyMiddleware(middleware));
        // This is the reason we need to be an enhancer, rather than a middleware.
        // We use this (along with the wrapReducer function above) to dispatch an
        // action that initializes the store without needing to fetch it synchronously.
        // I don't know why it yells about this "floating" when we clearly handle it
        // eslint-disable-next-line @typescript-eslint/no-floating-promises
        __ElectronReduxBridge.getMainState().then((mainState) => {
            console.log('dispatching replacestate', mainState);
            store.dispatch(replaceState(mainState));
        });
        // XXX: TypeScript is dumb. If you return the call to createStore
        // immediately it's fine, but even assigning it to a constant and returning
        // will make it freak out. We fix this with the line below the return.
        return store;
        // XXX: Even though this is unreachable, it fixes the type signature????
        return store;
    };
};
exports.syncRenderer = syncRenderer;
