"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.sendAction = exports.subscribeToActions = exports.getMainState = exports.preload = void 0;
const electron_1 = require("electron");
const helpers_1 = require("../helpers");
const preload = () => {
    const bridge = {
        getMainState,
        subscribeToActions,
        sendAction,
    };
    // contextBridge will throw an error if contextIsolation is not enabled, so
    // we try to see if it works, and if not we mutate the window directly.
    try {
        electron_1.contextBridge.exposeInMainWorld('__ElectronReduxBridge', bridge);
    }
    catch {
        window.__ElectronReduxBridge = bridge;
    }
};
exports.preload = preload;
async function getMainState() {
    const state = await electron_1.ipcRenderer.invoke('electron-redux.FETCH_STATE').catch((error) => {
        // eslint-disable-next-line no-console
        console.error(error);
        throw new Error('No Redux store found in main process. Did you use the syncMain enhancer?');
    });

    console.log('preload main state', state);
    // We do some fancy hydration on certain types like Map and Set.
    // See also `freeze`
    const hydratedState = JSON.parse(state, helpers_1.hydrate);
    return hydratedState;
}
exports.getMainState = getMainState;
function subscribeToActions(store) {
    electron_1.ipcRenderer.on('ACTION', (_, action) => {
        console.log('preload renderer received action', action, store.getState());
        store.dispatch(helpers_1.stopForwarding(action));
        console.log('preload renderer dispatched action', helpers_1.stopForwarding(action), store.getState());
    });
}
exports.subscribeToActions = subscribeToActions;
function sendAction(action) {
    electron_1.ipcRenderer.send('ACTION', action);
}
exports.sendAction = sendAction;
